package com.shxy.xymanager_admin.controller;

import com.shxy.xymanager_common.annotation.Log;
import com.shxy.xymanager_common.base.BaseController;
import com.shxy.xymanager_common.base.ResponseReult;
import com.shxy.xymanager_common.bean.ServiceBody;
import com.shxy.xymanager_common.bean.ServiceStatus;
import com.shxy.xymanager_common.model.DyLineTreeAndChannelListModel;
import com.shxy.xymanager_common.model.TerminalAllChannelListModel;
import com.shxy.xymanager_common.model.TerminalChannelListModel;
import com.shxy.xymanager_common.model.TerminalChannelMapperListModel;
import com.shxy.xymanager_common.vo.*;
import com.shxy.xymanager_service.service.TerminalChannelService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;


@Api(value = "通道接口", tags = "通道相关")
@RestController
@Slf4j
public class ChannelController extends BaseController {

    @Autowired
    TerminalChannelService terminalChannelService;


    @ApiOperation(value = "获取所有通道列表分页", notes = "获取所有通道列表接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getChannelList")
    @Log(title = "获取所有通道列表分页", type = "查询")
    public ResponseReult<TerminalChannelListModel> getChannelList(@RequestBody @Validated PageVo vo) {
        ServiceBody<TerminalChannelListModel> serviceBody = terminalChannelService.getChannelList(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "获取所有通道列表", notes = "获取所有通道列表接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getAllChannelList")
    @Log(title = "获取所有通道列表", type = "查询")
    public ResponseReult<TerminalAllChannelListModel> getAllChannelList() {
        ServiceBody<TerminalAllChannelListModel> serviceBody = terminalChannelService.getAllChannelList();
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "新增通道接口", notes = "新增通道接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/addChannelList")
    @Log(title = "新增通道接口", type = "新增")
    public ResponseReult<String> addChannelList(@RequestBody @Validated TerminalChannelVo vo) {
        ServiceBody<String> serviceBody = terminalChannelService.addChannelList(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }


    @ApiOperation(value = "修改通道接口", notes = "获取通道列表接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/updateChannelList")
    @Log(title = "修改通道列表", type = "修改")
    public ResponseReult<String> updateChannelList(@RequestBody @Validated UpdateTerminalChannelVo vo) {
        ServiceBody<String> serviceBody = terminalChannelService.updateChannelList(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "删除通道接口", notes = "获取通道列表接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/deleteChannelList")
    @Log(title = "删除通道接口", type = "修改")
    public ResponseReult<String> deleteChannelList(@RequestBody @Validated TerminalChannelIdListVo vo) {
        ServiceBody<String> serviceBody = terminalChannelService.deleteChannelList(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "根据装置号获取通道接口", notes = "根据装置号获取通道接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getChannelByTermid")
    @Log(title = "根据装置号获取通道接口", type = "查询")
    public ResponseReult<TerminalChannelMapperListModel> getChannelByTermid(@RequestBody @Validated TerminalIdVo vo) {
        ServiceBody<TerminalChannelMapperListModel> serviceBody = terminalChannelService.getChannelByTermid(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "获取所有通道树状列表接口", notes = "获取所有通道树状列表接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getChannelTreeList")
    @Log(title = "获取所有通道树状列表", type = "查询")
    public ResponseReult<DyLineTreeAndChannelListModel> getChannelTreeList(@RequestBody @Validated TerminalIdVo vo) {
        ServiceBody<DyLineTreeAndChannelListModel> serviceBody = terminalChannelService.getChannelTreeList(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }
}
