package com.shxy.xymanager_admin.controller;

import com.shxy.xymanager_common.annotation.Log;
import com.shxy.xymanager_common.base.BaseController;
import com.shxy.xymanager_common.base.ResponseReult;
import com.shxy.xymanager_common.bean.ServiceBody;
import com.shxy.xymanager_common.bean.ServiceStatus;
import com.shxy.xymanager_common.model.LineAndGtAndChannelListModel;
import com.shxy.xymanager_common.model.LineListModel;
import com.shxy.xymanager_common.model.DyLineTreeListModel;
import com.shxy.xymanager_common.vo.*;
import com.shxy.xymanager_service.service.LineService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;


@Api(value = "线路接口", tags = "线路相关")
@RestController
@Slf4j
public class LineController extends BaseController {

    @Autowired
    LineService lineService;

    @ApiOperation(value = "获取线路列表", notes = "获取线路列表接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getLineList")
    @Log(title = "获取线路列表", type = "查询")
    public ResponseReult<LineListModel> getLineList(@RequestBody @Validated PageVo vo) {
        ServiceBody<LineListModel> serviceBody = lineService.getLineList(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }


    @ApiOperation(value = "添加线路", notes = "添加线路接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/addLine")
    @Log(title = "添加线路", type = "新增")
    public ResponseReult<String> addLine(@RequestBody @Validated LineVo vo) {
        ServiceBody<String> serviceBody = lineService.addLine(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "删除线路", notes = "删除线路接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/deleteLine")
    @Log(title = "删除线路", type = "修改")
    public ResponseReult<String> deleteLine(@RequestBody @Validated LineIdVo vo) {
        ServiceBody<String> serviceBody = lineService.deleteLine(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "修改线路", notes = "修改线路接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/updateLine")
    @Log(title = "修改线路", type = "修改")
    public ResponseReult<String> updateLine(@RequestBody @Validated UpdateLineVo vo) {
        ServiceBody<String> serviceBody = lineService.updateLine(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "电压线路杆塔通道查询", notes = "电压线路杆塔通道查询查询", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getLineAndGt")
    @Log(title = "电压线路杆塔通道查询", type = "查询")
    public ResponseReult<LineAndGtAndChannelListModel> getDyLineAndGt(@RequestBody @Validated LineAndGtAndChannelVo vo) {
        ServiceBody<LineAndGtAndChannelListModel> serviceBody = lineService.getLineAndGt(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "线路和杆塔列表", notes = "线路和杆塔列表查询", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getLineAndGtList")
    @Log(title = "线路和杆塔列表查询", type = "查询")
    public ResponseReult<LineAndGtAndChannelListModel> getLineAndGtList(@RequestBody @Validated LineAndGtVo vo) {
        ServiceBody<LineAndGtAndChannelListModel> serviceBody = lineService.getLineAndGtList(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }
}
