package com.shxy.xymanager_admin.controller;

import cn.hutool.json.JSONObject;
import com.shxy.xymanager_common.annotation.Log;
import com.shxy.xymanager_common.base.BaseController;
import com.shxy.xymanager_common.base.ResponseReult;
import com.shxy.xymanager_common.bean.ServiceBody;
import com.shxy.xymanager_common.bean.ServiceStatus;
import com.shxy.xymanager_common.model.*;
import com.shxy.xymanager_common.util.HeaderUtil;
import com.shxy.xymanager_common.vo.*;
import com.shxy.xymanager_service.service.OpenService;
import com.shxy.xymanager_service.service.TerminalPhotoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpHeaders;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;


@Api(value = "精益化平台接口", tags = "精益化平台相关")
@RestController
@Slf4j
public class OpenController extends BaseController {

    @Autowired
    TerminalPhotoService terminalPhotoService;

    @Autowired
    OpenService openService;


    @ApiOperation(value = "对外图片查询", notes = "对外图片查询", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getPhotoListForOpen")
    @Log(title = "对外图片查询", type = "查询")
    public ResponseReult<TerminalPhotoListForOpenModel> getPhotoListForOpen(@RequestHeader HttpHeaders headers, @RequestBody @Validated OpenTerminalAndTimeVo vo) {
        String requestIp = HeaderUtil.getRequestIp(headers);
        ServiceBody<TerminalPhotoListForOpenModel> serviceBody = terminalPhotoService.getPhotoListForOpen(requestIp,vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "第三方登录认证接口", notes = "第三方登录认证接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 0, message = "请求成功"), @ApiResponse(code = 1, message = "用户名错误"), @ApiResponse(code = 2, message = "密码错误")})
    @RequestMapping("/cmaUserLogin")
    @Log(title = "第三方登录认证接口", type = "查询")
    public JSONObject cmaUserLogin(@RequestBody @Validated UserLoginVo vo) {
        JSONObject serviceBody = openService.cmaUserLogin(vo);
        return serviceBody;
    }

    @ApiOperation(value = "远程拍照(短视频)控制", notes = "远程拍照(短视频)控制接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 0, message = "请求成功"), @ApiResponse(code = 1, message = "用户名错误"), @ApiResponse(code = 2, message = "密码错误")})
    @RequestMapping("/ctrlCmaDeviceCapture")
    @Log(title = "远程拍照(短视频)控制", type = "查询")
    public JSONObject ctrlCmaDeviceCapture(@RequestBody @Validated OpenDeviceCaptureVo vo) {
        JSONObject serviceBody = openService.ctrlCmaDeviceCapture(vo);
        return serviceBody;
    }

    @ApiOperation(value = "查询装置状态", notes = "查询装置状态接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 0, message = "请求成功"), @ApiResponse(code = 1, message = "用户名错误"), @ApiResponse(code = 2, message = "密码错误")})
    @RequestMapping("/cmaDeviceStatus")
    @Log(title = "查询装置状态接口", type = "查询")
    public JSONObject cmaDeviceStatus(@RequestBody @Validated OpenCmdidVo vo) {
        JSONObject serviceBody = openService.cmaDeviceStatus(vo);
        return serviceBody;
    }
}
