package com.shxy.xymanager_admin.controller;


import com.shxy.xymanager_common.base.ResponseReult;
import com.shxy.xymanager_common.bean.ServiceBody;
import com.shxy.xymanager_common.bean.ServiceStatus;
import com.shxy.xymanager_common.bean.SysUser;
import com.shxy.xymanager_common.entity.SysUserSession;
import com.shxy.xymanager_common.model.SysUserModel;
import com.shxy.xymanager_common.vo.PageVo;
import com.shxy.xymanager_common.vo.SysUserUpdateVo;
import com.shxy.xymanager_common.vo.SysUserVo;
import com.shxy.xymanager_service.service.LoginService;
import com.shxy.xymanager_service.service.SysUserService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

@Api(value = "登录验证", tags = "登录验证")
@RestController
@Slf4j
public class SysLoginController {

    @Autowired
    private LoginService loginService;

    @Autowired
    SysUserService sysUserService;

    /**
     * @Description 登录方法
     *
     * @param sysUser
     * @return ResponseReult
     */
    @ApiOperation(value = "登录", notes = "登录", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/login")
    public ResponseReult<SysUserSession> login(@RequestBody SysUser sysUser) {
        ServiceBody<SysUserSession> serviceBody = loginService.remoteLogin(sysUser);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    /**
     * 新增用户
     *
     * @param vo
     * @return
     */
    @ApiOperation(value = "修改用户", notes = "修改用户", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/updateUser")
    public ResponseReult<String> updateUser(@RequestBody @Validated SysUserUpdateVo vo) {
        ServiceBody<String> serviceBody = sysUserService.updateUser(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }


    @ApiOperation(value = "新增用户", notes = "新增用户", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/addUser")
    public ResponseReult<String> add(@RequestBody @Validated SysUserVo vo) {
        ServiceBody<String> serviceBody = sysUserService.addUser(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }


    /**
     * 查询用户列表
     *
     * @return
     */

    @ApiOperation(value = "查询用户列表", notes = "查询用户列表", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/userList")
    public ResponseReult<SysUserModel> userList(@RequestBody @Validated PageVo vo) {
        ServiceBody<SysUserModel> serviceBody = sysUserService.selectUserList(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }


    /**
     * 查询用户列表
     *
     * @return
     */

    @ApiOperation(value = "删除用户", notes = "删除用户", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/deleteUser")
    public ResponseReult<String> deleteUser(@RequestParam("uid") String uid) {
        ServiceBody<String> serviceBody = sysUserService.deleteUserById(uid);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

}
