package com.shxy.xymanager_admin.controller;

import com.shxy.xymanager_common.annotation.Log;
import com.shxy.xymanager_common.base.BaseController;
import com.shxy.xymanager_common.base.ResponseReult;
import com.shxy.xymanager_common.bean.ServiceBody;
import com.shxy.xymanager_common.bean.ServiceStatus;
import com.shxy.xymanager_common.model.GetModel;
import com.shxy.xymanager_common.model.SystemConfigModel;
import com.shxy.xymanager_common.model.UpperComputerInfoModel;
import com.shxy.xymanager_common.vo.SystemConfigReqVo;
import com.shxy.xymanager_common.vo.SystemConfigVo;
import com.shxy.xymanager_common.vo.TerminalUpperComputerVo;
import com.shxy.xymanager_service.service.SystemConfigService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;


@Api(value = "全局参数设置", tags = "全局参数设置")
@RestController
@Slf4j
public class SystemConfigController extends BaseController {

    @Autowired
    SystemConfigService configService;

    @ApiOperation(value = "获取全局配置触发", notes = "获取全局配置触发接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getSystemConfigGet")
    @Log(title = "获取全局配置触发接口", type = "查询")
    public ResponseReult<GetModel> getSystemConfigGet(@RequestParam("id") String id) {
        ServiceBody<GetModel> serviceBody = configService.getSystemConfig(id);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "获取全局配置", notes = "获取全局配置表接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getSystemConfig")
    @Log(title = "获取全局配置", type = "查询")
    public ResponseReult<SystemConfigModel> getSystemConfig(@RequestBody @Validated SystemConfigReqVo vo) {
        ServiceBody<SystemConfigModel> serviceBody = configService.getSystemConfigDetail(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "更新配置", notes = "更新配置", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/updateSystemConfig")
    @Log(title = "更新配置", type = "查询")
    public ResponseReult updateSystemConfig(@RequestBody SystemConfigVo vo) {
        ServiceBody serviceBody = configService.updateSystemConfig(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "获取上位机信息触发", notes = "获取上位机信息触发接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/upperComputerGet")
    @Log(title = "获取上位机信息触发", type = "查询")
    public ResponseReult<GetModel> upperComputerGet(@RequestParam("cmdId") String cmdId) {
        ServiceBody<GetModel> serviceBody = configService.upperComputerGet(cmdId);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "获取上位机信息", notes = "获取上位机信息接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getUpperComputerInfo")
    @Log(title = "获取上位机信息", type = "查询")
    public ResponseReult<UpperComputerInfoModel> getUpperComputerInfo(@RequestBody @Validated TerminalUpperComputerVo vo) {
        ServiceBody<UpperComputerInfoModel> serviceBody = configService.getUpperComputerInfo(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }


}
