package com.shxy.xymanager_admin.controller;

import com.shxy.xymanager_common.annotation.Log;
import com.shxy.xymanager_common.base.BaseController;
import com.shxy.xymanager_common.base.ResponseReult;
import com.shxy.xymanager_common.bean.ServiceBody;
import com.shxy.xymanager_common.bean.ServiceStatus;
import com.shxy.xymanager_common.model.*;
import com.shxy.xymanager_common.util.HeaderUtil;
import com.shxy.xymanager_common.vo.*;
import com.shxy.xymanager_service.service.TerminalAlarmService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpHeaders;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;


@Api(value = "告警接口", tags = "告警接口相关")
@RestController
@Slf4j
public class TerminalAlarmController extends BaseController {

    @Autowired
    TerminalAlarmService terminalAlarmService;

    @ApiOperation(value = "获取告警列表", notes = "获取告警列表接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getTerminalAlarmList")
    @Log(title = "获取告警列表", type = "查询")
    public ResponseReult<TerminalAlarmListModel> getTerminalAlarmList(@RequestHeader HttpHeaders headers, @RequestBody @Validated TerminalAlarmSelectVo vo) {
        String requestIp = HeaderUtil.getRequestIp(headers);
        ServiceBody<TerminalAlarmListModel> serviceBody = terminalAlarmService.getTerminalAlarmList(requestIp,vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "更改告警列表未读状态", notes = "更改告警列表未读状态", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/readAlarm")
    @Log(title = "更改告警列表未读状态", type = "修改")
    public ResponseReult<Boolean> readAlarm(@RequestBody @Validated TerminalAlarmIdVo vo) {
        ServiceBody<Boolean> serviceBody = terminalAlarmService.readAlarm(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }


    @ApiOperation(value = "获取告警分类列表", notes = "获取告警分类列表", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getAlarmTypeList")
    @Log(title = "获取告警分类列表", type = "查询")
    public ResponseReult<TerminalImgAlarmParamsModel> getAlarmTypeList() {
        ServiceBody<TerminalImgAlarmParamsModel> serviceBody = terminalAlarmService.getAlarmTypeList();
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }


    @ApiOperation(value = "修改告警分类列表", notes = "修改告警分类列表", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/updateAlarmTypeList")
    @Log(title = "修改告警分类列表", type = "修改")
    public ResponseReult<String> updateAlarmTypeList(@RequestBody @Validated UpdateTerminalAlarmParamsVo vo) {
        ServiceBody<String> serviceBody = terminalAlarmService.updateAlarmTypeList(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

}
