package com.shxy.xymanager_admin.controller;

import com.shxy.xymanager_common.annotation.Log;
import com.shxy.xymanager_common.base.BaseController;
import com.shxy.xymanager_common.base.ResponseReult;
import com.shxy.xymanager_common.bean.ServiceBody;
import com.shxy.xymanager_common.bean.ServiceStatus;
import com.shxy.xymanager_common.model.*;
import com.shxy.xymanager_common.util.HeaderUtil;
import com.shxy.xymanager_common.vo.*;
import com.shxy.xymanager_service.service.TerminalService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpHeaders;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;


@Api(value = "设备接口", tags = "设备接口相关")
@RestController
@Slf4j
public class TerminalController extends BaseController {

    @Autowired
    TerminalService terminalService;

    @ApiOperation(value = "获取设备列表", notes = "获取设备列表接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getTerminalList")
    @Log(title = "获取设备列表", type = "查询")
    public ResponseReult<TerminalListModel> getTerminalList(@RequestBody @Validated TerminalSelectVo vo) {
        ServiceBody<TerminalListModel> serviceBody = terminalService.getTerminalList(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "获取绘制图标", notes = "绘制坐标保存接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getCoordinate")
    @Log(title = "获取绘制图标", type = "查询")
    public ResponseReult<PhotoMarkModel> getCoordinate(@RequestHeader HttpHeaders headers, @RequestBody @Validated MarkReqVo vo) {
        String requestIp = HeaderUtil.getRequestIp(headers);
        ServiceBody<PhotoMarkModel> serviceBody = terminalService.getCoordinate(requestIp, vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "绘制坐标保存", notes = "绘制坐标保存接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/updateCoordinate")
    @Log(title = "绘制坐标保存", type = "更新")
    public ResponseReult<String> coordinate(@RequestBody @Validated PhotoMarkVo vo) {
        ServiceBody<String> serviceBody = terminalService.updateCoordinate(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "添加设备", notes = "添加设备接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/addTerminal")
    @Log(title = "新增设备列表", type = "新增")
    public ResponseReult<String> addTerminal(@RequestBody @Validated TerminalVo vo) {
        ServiceBody<String> serviceBody = terminalService.addTerminal(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "修改设备", notes = "修改设备接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/updateTerminal")
    @Log(title = "修改设备", type = "修改")
    public ResponseReult<String> updateTerminal(@RequestBody @Validated UpdateTerminalVo vo) {
        ServiceBody<String> serviceBody = terminalService.updateTerminal(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "删除装置", notes = "删除装置接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/deleteTerminal")
    @Log(title = "删除装置列表", type = "修改")
    public ResponseReult<String> deleteTerminal(@RequestBody @Validated TerminalIdListVo vo) {
        ServiceBody<String> serviceBody = terminalService.deleteTerminal(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "装置复位", notes = "装置复位接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/resetTerminal")
    @Log(title = "装置复位", type = "修改")
    public ResponseReult<String> resetTerminal(@RequestParam("cmId") String cmId) {
        ServiceBody<String> serviceBody = terminalService.resetTerminal(cmId);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "获取装置触发", notes = "获取装置信息接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getTerminalStatus")
    @Log(title = "获取装置触发", type = "查询")
    public ResponseReult<TerminalStatusModel> getTerminalStatus(@RequestParam("termId") Integer termId) {
        ServiceBody<TerminalStatusModel> serviceBody = terminalService.getTerminalStatus(termId);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "获取最新装置运行状态", notes = "获取装置信息接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getLastedTerminalStatus")
    @Log(title = "获取最新装置运行状态", type = "修改")
    public ResponseReult<TerminalStatusInfoModel> getLastedTerminalStatus(@RequestBody @Validated TerminalStatusVo vo) {
        ServiceBody<TerminalStatusInfoModel> serviceBody = terminalService.getLastedTerminalStatus(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "图像装置ID设置", notes = "图像装置ID设置", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/updateTerminalId")
    @Log(title = "图像装置ID设置", type = "修改")
    public ResponseReult<TerminalUpdateModel> updateTerminalId(@RequestBody @Validated TerminalIdUpdateVo vo) {
        ServiceBody<TerminalUpdateModel> serviceBody = terminalService.updateTerminalId(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "图像装置ID查询触发", notes = "图像装置ID查询触发接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/terminalIdGet")
    @Log(title = "图像装置ID查询触发", type = "修改")
    public ResponseReult<GetModel> terminalIdGet(@RequestBody @Validated TerminalIdUpdateVo vo) {
        ServiceBody<GetModel> serviceBody = terminalService.terminalIdGet(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "图像装置ID查询", notes = "图像装置ID查询接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/selectTerminalId")
    @Log(title = "图像装置ID查询", type = "修改")
    public ResponseReult<TerminalIdModel> selectTerminalId(@RequestParam("requestId") Integer requestId) {
        ServiceBody<TerminalIdModel> serviceBody = terminalService.selectTerminalId(requestId);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "根据通道编号获取设备列表", notes = "根据通道编号获取设备列表", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getTermListByChannel")
    @Log(title = "获取设备列表", type = "查询")
    public ResponseReult<DyLineAndTermModel> getTermListByChannel(@RequestBody @Validated TerminalChannelIdVo vo) {
        ServiceBody<DyLineAndTermModel> serviceBody = terminalService.getTermListByChannel(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "获取装置在线状态", notes = "获取装置在线状态", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getTermStatus")
    @Log(title = "获取装置在线状态", type = "查询")
    public ResponseReult<TermStatusModel> getTermStatus(@RequestParam("termId") @Validated Integer termId) {
        ServiceBody<TermStatusModel> serviceBody = terminalService.getTermStatus(termId);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "获取装置数据库信息", notes = "获取装置数据库信息", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getLastTermInfo")
    @Log(title = "获取装置数据库信息", type = "查询")
    public ResponseReult<TerminalStatusInfoModel> getLastTermInfo(@RequestParam("termId") @Validated Integer termId) {
        ServiceBody<TerminalStatusInfoModel> serviceBody = terminalService.getLastTermInfo(termId);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

}
