package com.shxy.xymanager_admin.controller;

import cn.hutool.core.date.DateTime;
import com.shxy.xymanager_common.annotation.Log;
import com.shxy.xymanager_common.base.BaseController;
import com.shxy.xymanager_common.base.ResponseReult;
import com.shxy.xymanager_common.bean.ServiceBody;
import com.shxy.xymanager_common.bean.ServiceStatus;
import com.shxy.xymanager_common.model.GetModel;
import com.shxy.xymanager_common.model.TerminalGpsModel;
import com.shxy.xymanager_common.vo.*;
import com.shxy.xymanager_service.service.TerminalGpsService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;


@Api(value = "设备GPS接口", tags = "设备GPS接口相关")
@RestController
@Slf4j
public class TerminalGPSController extends BaseController {

    @Autowired
    TerminalGpsService terminalGpsService;

    @ApiOperation(value = "开启关闭GPS", notes = "开启关闭GPS接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/setTermGPS")
    @Log(title = "开启关闭GPS", type = "修改")
    public ResponseReult<String> setTermGPS(@RequestBody @Validated TerminalIdAndGpsVo vo) {
        ServiceBody<String> serviceBody = terminalGpsService.setTermGPS(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }


    @ApiOperation(value = "获取GPS位置", notes = "获取GPS位置接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getTermGPS")
    @Log(title = "获取GPS位置", type = "查询")
    public ResponseReult<TerminalGpsModel> getTermGPS(@RequestBody @Validated TerminalIdVo vo) {
        ServiceBody<TerminalGpsModel> serviceBody = terminalGpsService.getTermGPS(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "获取GPS位置触发", notes = "获取GPS位置触发接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getTermGPSPosition")
    @Log(title = "获取GPS位置触发", type = "查询")
    public ResponseReult<DateTime> getReturnedTermGPS(@RequestBody @Validated TerminalGpsVo vo) {
        ServiceBody<DateTime> serviceBody = terminalGpsService.getReturnedGPS(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "获取数据库GPS位置数据", notes = "获取数据库GPS位置数据", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getTermLastGPSPosition")
    @Log(title = "获取数据库GPS位置数据", type = "查询")
    public ResponseReult<TerminalGpsModel> getTermLastGPSPosition(@RequestParam("termId") @Validated Integer termId) {
        ServiceBody<TerminalGpsModel> serviceBody = terminalGpsService.getTermLastGPSPosition(termId);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

}
