package com.shxy.xymanager_admin.controller;

import com.shxy.xymanager_common.annotation.Log;
import com.shxy.xymanager_common.base.BaseController;
import com.shxy.xymanager_common.base.ResponseReult;
import com.shxy.xymanager_common.bean.ServiceBody;
import com.shxy.xymanager_common.bean.ServiceStatus;
import com.shxy.xymanager_common.model.*;
import com.shxy.xymanager_common.util.HeaderUtil;
import com.shxy.xymanager_common.vo.*;
import com.shxy.xymanager_service.service.TerminalPhotoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpHeaders;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.Date;


@Api(value = "图片接口", tags = "图片接口相关")
@RestController
@Slf4j
public class TerminalPhotoController extends BaseController {

    @Autowired
    TerminalPhotoService terminalPhotoService;

    @ApiOperation(value = "获取图片列表", notes = "获取图片列表接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getTerminalPhotoList")
    @Log(title = "获取图片列表", type = "查询")
    public ResponseReult<TerminalPhotoListModel> getTerminalPhotoList(@RequestHeader HttpHeaders headers, @RequestBody @Validated TerminalAndChannelIdAndTimeVo vo) {
        String requestIp = HeaderUtil.getRequestIp(headers);
        ServiceBody<TerminalPhotoListModel> serviceBody = terminalPhotoService.getTerminalPhotoList(requestIp, vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "主动拍照", notes = "主动拍照接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getLatestPhoto")
    @Log(title = "主动拍照", type = "查询")
    public ResponseReult<Date> getLatestPhoto(@RequestBody @Validated TerminalPhotoVo vo) {
        ServiceBody<Date> serviceBody = terminalPhotoService.getLatestPhoto(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "拍照时间表查询触发", notes = "拍照时间表查询触发", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/selectPhotoTimeGet")
    @Log(title = "拍照时间表查询触发", type = "查询")
    public ResponseReult<GetModel> selectPhotoTimeGet(@RequestBody @Validated TerminalPhotoTimeGetVo vo) {
        ServiceBody<GetModel> serviceBody = terminalPhotoService.selectPhotoTimeGet(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "拍照时间表查询", notes = "拍照时间表查询", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/selectPhotoTime")
    @Log(title = "拍照时间表查询", type = "查询")
    public ResponseReult<TerminalScheduleRuleTimeListModel> selectPhotoTime(@RequestBody @Validated TerminalReqPhotoTimeVo vo) {
        ServiceBody<TerminalScheduleRuleTimeListModel> serviceBody = terminalPhotoService.selectPhotoTime(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "图片查询", notes = "图片查询接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getPhotoList")
    @Log(title = "图片查询", type = "查询")
    public ResponseReult<TerminalPhotoSelectListModel> getPhotoList(@RequestHeader HttpHeaders headers, @RequestBody @Validated TerminalPhotoSelectVo vo) {
        String requestIp = HeaderUtil.getRequestIp(headers);
        ServiceBody<TerminalPhotoSelectListModel> serviceBody = terminalPhotoService.getPhotoList(requestIp, vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "最新图片查询", notes = "图片查询接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getReturnedPhoto")
    @Log(title = "最新图片查询", type = "查询")
    public ResponseReult<Boolean> getReturnedPhoto(@RequestBody @Validated ReturnedPhotoVo vo) {
        ServiceBody<Boolean> serviceBody = terminalPhotoService.getReturnedPhoto(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "图片轮询", notes = "图片轮询接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getPhotoBanner")
    @Log(title = "图片轮询", type = "查询")
    public ResponseReult<TerminalPhotosModel> getPhotoBanner(@RequestHeader HttpHeaders headers, @RequestBody @Validated PageVo vo) {
        String requestIp = HeaderUtil.getRequestIp(headers);
        ServiceBody<TerminalPhotosModel> serviceBody = terminalPhotoService.getPhotoBanner(requestIp, vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "最新图片采集参数触发", notes = "最新图片采集参数触发", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getPhotoQueryParamList")
    @Log(title = "最新图片采集参数触发", type = "查询")
    public ResponseReult<GetModel> getPhotoQueryParamList(@RequestBody @Validated ReturnedPhotoParamsGetVo vo) {
        ServiceBody<GetModel> serviceBody = terminalPhotoService.getPhotoQueryParam(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "图像采集参数查询", notes = "图像采集参数查询", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/photoQueryParamGet")
    @Log(title = "图像采集参数查询", type = "查询")
    public ResponseReult<TerminalPhotosParamsModel> getLastedPhotoQueryParam(@RequestBody @Validated ReturnedPhotoParamsVo vo) {
        ServiceBody<TerminalPhotosParamsModel> serviceBody = terminalPhotoService.getLastedPhotoQueryParam(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "图像采集参数设置", notes = "图像采集参数设置", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/updatePhotoParam")
    @Log(title = "图像采集参数设置", type = "查询")
    public ResponseReult<String> addOrUpdatePhotoParams(@RequestBody @Validated PhotoParamsVo vo) {
        ServiceBody<String> serviceBody = terminalPhotoService.addOrUpdatePhotoParams(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }


    @ApiOperation(value = "历史图片", notes = "历史图片接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getHistoryList")
    @Log(title = "历史图片", type = "查询")
    public ResponseReult<TerminalPhotoSelectListModel> getHistoryList(@RequestHeader HttpHeaders headers, @RequestBody @Validated TermIdAndChannelIdVo vo) {
        String requestIp = HeaderUtil.getRequestIp(headers);
        ServiceBody<TerminalPhotoSelectListModel> serviceBody = terminalPhotoService.getHistoryList(requestIp, vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

}
