package com.shxy.xymanager_admin.controller;

import com.shxy.xymanager_common.annotation.Log;
import com.shxy.xymanager_common.base.BaseController;
import com.shxy.xymanager_common.base.ResponseReult;
import com.shxy.xymanager_common.bean.ServiceBody;
import com.shxy.xymanager_common.bean.ServiceStatus;
import com.shxy.xymanager_common.model.*;
import com.shxy.xymanager_common.vo.*;
import com.shxy.xymanager_service.service.TerminalScheduleRuleService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;


@Api(value = "任务规则接口", tags = "任务规则接口相关")
@RestController
@Slf4j
public class TerminalScheduleRuleController extends BaseController {

    @Autowired
    TerminalScheduleRuleService terminalScheduleRuleService;

    @ApiOperation(value = "获取任务规则列表", notes = "获取任务规则列表接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getScheduleRulelList")
    @Log(title = "获取任务规则列表", type = "查询")
    public ResponseReult<TerminalScheduleRuleListModel> getSchedulelRuleList(@RequestBody @Validated PageVo vo) {
        ServiceBody<TerminalScheduleRuleListModel> serviceBody = terminalScheduleRuleService.getScheduleRuleList(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "获取单个任务规则", notes = "获取单个任务规则接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getSingleScheduleRule")
    @Log(title = "获取单个任务规则", type = "查询")
    public ResponseReult<TerminalScheduleRuleModel> getSingleScheduleRule(@RequestBody @Validated ScheduleIdVo vo) {
        ServiceBody<TerminalScheduleRuleModel> serviceBody = terminalScheduleRuleService.getSingleScheduleRule(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "添加任务规则列表", notes = "添加任务规则列表接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/addSchelduleRuleList")
    @Log(title = "添加任务规则列表", type = "新增")
    public ResponseReult<String> addSchedulelRuleList(@RequestBody @Validated ScheduleListVo vo) {
        ServiceBody<String> serviceBody = terminalScheduleRuleService.addSchedulelRuleList(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "修改任务规则", notes = "修改任务规则接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/updateSchelduleRule")
    @Log(title = "修改任务规则", type = "修改")
    public ResponseReult<String> updateSchelduleRule(@RequestBody @Validated UpdateScheduleListVo vo) {
        ServiceBody<String> serviceBody = terminalScheduleRuleService.updateSchelduleRule(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "删除任务规则", notes = "删除任务规则接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/deleteSchelduleRule")
    @Log(title = "删除任务规则", type = "修改")
    public ResponseReult<String> deleteSchelduleRule(@RequestBody @Validated ScheduleIdListVo vo) {
        ServiceBody<String> serviceBody = terminalScheduleRuleService.deleteSchelduleRule(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "拍照任务规则关联设备", notes = "拍照任务规则关联设备接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/relateSchelduleRule")
    @Log(title = "关联任务规则", type = "修改")
    public ResponseReult<GetScheduleRequestIdListModel> relateSchelduleRule(@RequestBody @Validated RelateTerminalListRuleIdVo vo) {
        ServiceBody<GetScheduleRequestIdListModel> serviceBody = terminalScheduleRuleService.relateSchelduleRule(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "根据通道和装置编号获取拍照时间表", notes = "根据通道和装置编号获取拍照时间表", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getChannelSchelduleRule")
    @Log(title = "根据通道和装置编号获取拍照时间表", type = "修改")
    public ResponseReult<TerminalScheduleRuleTimeListModel> getChannelSchelduleRule(@RequestBody @Validated TerminalAndChannelIdVo vo) {
        ServiceBody<TerminalScheduleRuleTimeListModel> serviceBody = terminalScheduleRuleService.getChannelSchelduleRule(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "通过Cma获取装置的实际拍照时间调用", notes = "通过Cma获取装置的实际拍照时间调用", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/cmaSchelduleDetials")
    @Log(title = "通过Cma获取装置的实际拍照时间调用", type = "查询")
    public ResponseReult<GetModel> cmaSchelduleDetials(@RequestBody @Validated TerminalAndChannelIdVo vo) {
        ServiceBody<GetModel> serviceBody = terminalScheduleRuleService.cmaSchelduleDetials(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "获取Cma调用实际拍照时间的结果", notes = "获取Cma调用实际拍照时间的结果", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getCmaSchelduleDetials")
    @Log(title = "获取Cma调用实际拍照时间的结果", type = "查询")
    public ResponseReult<TerminalScheduleRuleTimeListModel> getCmaSchelduleDetials(@RequestBody @Validated RequestIdVo vo) {
        ServiceBody<TerminalScheduleRuleTimeListModel> serviceBody = terminalScheduleRuleService.getCmaSchelduleDetials(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "根据requestid查询时间表下发状态", notes = "根据requestid查询时间表下发状态", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getCmaSchelduleUpload")
    @Log(title = "根据requestid查询时间表下发状态", type = "查询")
    public ResponseReult<ScheduleRequestIdListModel> getCmaSchelduleUpload(@RequestBody @Validated RequestIdListVo vo) {
        ServiceBody<ScheduleRequestIdListModel> serviceBody = terminalScheduleRuleService.checkScheldule(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

}
