package com.shxy.xymanager_admin.controller;

import com.shxy.xymanager_common.annotation.Log;
import com.shxy.xymanager_common.base.BaseController;
import com.shxy.xymanager_common.base.ResponseReult;
import com.shxy.xymanager_common.bean.ServiceBody;
import com.shxy.xymanager_common.bean.ServiceStatus;
import com.shxy.xymanager_common.model.GetModel;
import com.shxy.xymanager_common.model.TerminalVideoParamsModel;
import com.shxy.xymanager_common.vo.VideoGetVo;
import com.shxy.xymanager_common.vo.VideoParamsVo;
import com.shxy.xymanager_service.service.TerminalVideoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;


@Api(value = "视频接口", tags = "视频接口相关")
@RestController
@Slf4j
public class TerminalVideoController extends BaseController {

    @Autowired
    TerminalVideoService terminalVideoService;

    @ApiOperation(value = "视频参数设置", notes = "视频参数设置接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/updateVideoParam")
    @Log(title = "视频参数设置", type = "查询")
    public ResponseReult<String> updateVideoParam(@RequestBody @Validated VideoParamsVo vo) {
        ServiceBody<String> serviceBody = terminalVideoService.updateVideoParam(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "视频参数查询触发", notes = "视频参数查询触发接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/videoParamGet")
    @Log(title = "视频参数查询触发", type = "查询")
    public ResponseReult<GetModel> videoParamGet(@RequestBody @Validated VideoGetVo vo) {
        ServiceBody<GetModel> serviceBody = terminalVideoService.videoParamGet(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "视频参数查询", notes = "视频参数查询接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/selectVideoParam")
    @Log(title = "视频参数查询", type = "查询")
    public ResponseReult<TerminalVideoParamsModel> selectVideoParam(@RequestParam("requestId") Integer requestId) {
        ServiceBody<TerminalVideoParamsModel> serviceBody = terminalVideoService.selectVideoParam(requestId);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }


}
