package com.shxy.xymanager_admin.controller;

import com.shxy.xymanager_common.annotation.Log;
import com.shxy.xymanager_common.base.BaseController;
import com.shxy.xymanager_common.base.ResponseReult;
import com.shxy.xymanager_common.bean.ServiceBody;
import com.shxy.xymanager_common.bean.ServiceStatus;
import com.shxy.xymanager_common.dto.TowerDto;
import com.shxy.xymanager_common.model.AllTowerListModel;
import com.shxy.xymanager_common.model.TowerListModel;
import com.shxy.xymanager_common.vo.PageVo;
import com.shxy.xymanager_common.vo.TowerIdVo;
import com.shxy.xymanager_common.vo.TowersVo;
import com.shxy.xymanager_common.vo.UpdateTowerVo;
import com.shxy.xymanager_service.service.TowerService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;


@Api(value = "杆塔接口", tags = "杆塔接口相关")
@RestController
@Slf4j
public class TowerController extends BaseController {

    @Autowired
    TowerService towerService;

    @ApiOperation(value = "新增杆塔", notes = "新增杆塔接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/addTower")
    @Log(title = "新增杆塔", type = "查询")
    public ResponseReult<String> addTower(@RequestBody @Validated TowersVo vo) {
        ServiceBody<String> serviceBody = towerService.addTower(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "获取杆塔列表", notes = "获取杆塔列表接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getTowerList")
    @Log(title = "获取杆塔列表", type = "查询")
    public ResponseReult<TowerListModel> getTowerList(@RequestBody @Validated PageVo vo) {
        ServiceBody<TowerListModel> serviceBody = towerService.getTowerList(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "获取杆塔", notes = "获取杆塔列表接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getTowerInfo")
    @Log(title = "获取杆塔", type = "查询")
    public ResponseReult<TowerDto> getTowerInfo(@RequestParam("id") Integer id) {
        ServiceBody<TowerDto> serviceBody = towerService.getTowerInfo(id);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "删除杆塔", notes = "删除杆塔接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/deleteTower")
    @Log(title = "删除杆塔", type = "修改")
    public ResponseReult<String> deleteTower(@RequestBody @Validated TowerIdVo vo) {
        ServiceBody<String> serviceBody = towerService.deleteTower(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "修改杆塔", notes = "修改杆塔接口", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/updateTower")
    @Log(title = "修改杆塔", type = "修改")
    public ResponseReult<String> updateTower(@RequestBody @Validated UpdateTowerVo vo) {
        ServiceBody<String> serviceBody = towerService.updateTower(vo);
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }

    @ApiOperation(value = "获取所有杆塔", notes = "获取所有杆塔", httpMethod = "POST")
    @ApiResponses({@ApiResponse(code = 200, message = "请求成功"), @ApiResponse(code = 400, message = "请求参数没填好"), @ApiResponse(code = 404, message = "请求路径没有或页面跳转路径不对")})
    @RequestMapping("/getAllTower")
    @Log(title = "获取所有杆塔", type = "查询")
    public ResponseReult<AllTowerListModel> getAllTower() {
        ServiceBody<AllTowerListModel> serviceBody = towerService.getAllTower();
        if (serviceBody.getCode() == ServiceStatus.SUCCESS) {
            return ResponseReult.success(serviceBody.getData());
        } else {
            return ResponseReult.error(serviceBody.getCode(), serviceBody.getMsg());
        }
    }


}
