package com.shxy.xymanager_common.base;

import com.shxy.xymanager_common.exception.IErrorCode;
import com.shxy.xymanager_common.util.http.HttpStatus;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;

// @ApiModel: 用对象来接收参数
@ApiModel(value = "接口返回", description = "接口响应返回")
public class ResponseReult<T> implements Serializable {
    /**
     * 返回对象
     */
    @ApiModelProperty(value = "返回对象", name = "返回对象")
    private T data;
    /**
     * 返回状态码
     */
    @ApiModelProperty(value = "返回状态码", name = "返回状态码", required = true)
    private int code;
    /**
     * 返回描述
     */
    @ApiModelProperty(value = "返回描述", name = "返回描述")
    private String msg;

    public T getData() {
        return data;
    }

    public void setData(T data) {
        this.data = data;
    }

    public int getCode() {
        return code;
    }

    public void setCode(int code) {
        this.code = code;
    }

    public void setCode(int code, String msg) {
        this.code = code;
        this.msg = msg;
    }

    public String getMsg() {
        return msg;
    }

    public void setMsg(String msg) {
        this.msg = msg;
    }

    /**
     * 返回成功消息
     *
     * @return 成功消息
     */
    public static <T> ResponseReult<T> success(T obj) {
        ResponseReult<T> success = ResponseReult.success();
        if (obj != null) {
            success.setData(obj);
        }
        return success;
    }

    /**
     * 返回成功消息
     *
     * @return 成功消息
     */
    public static <T> ResponseReult<T> success() {
        ResponseReult<T> response = new ResponseReult<>();
        response.setCode(HttpStatus.HTTP_OK, "操作成功");
        return response;
    }

    /**
     * 返回失败消息
     *
     * @return 失败消息
     */
    public static <T> ResponseReult<T> error() {
        ResponseReult<T> response = ResponseReult.error(HttpStatus.HTTP_INTERNAL_ERROR, "操作失败");
        return response;
    }

    /**
     * 返回失败消息
     *
     * @return 失败消息
     */
    public static <T> ResponseReult<T> error(int code, String msg) {
        ResponseReult<T> response = new ResponseReult<>();
        response.setCode(code, msg);
        return response;
    }

    /**
     * 失败返回结果
     *
     * @param errorCode 错误码
     */
    public static <T> ResponseReult<T> error(IErrorCode errorCode) {
        return ResponseReult.error(errorCode.getCode(), errorCode.getMessage());
    }

    /**
     * 失败返回结果
     *
     * @param message 错误信息
     */
    public static <T> ResponseReult<T> error(String message) {
        return ResponseReult.error(HttpStatus.HTTP_INTERNAL_ERROR, message);
    }

}
