package com.shxy.xymanager_common.exception;

import com.shxy.xymanager_common.base.ResponseReult;
import org.springframework.validation.BindException;
import org.springframework.validation.BindingResult;
import org.springframework.validation.FieldError;
import org.springframework.web.bind.MethodArgumentNotValidException;
import org.springframework.web.bind.annotation.ControllerAdvice;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ResponseBody;

import java.sql.SQLException;

/**
 * 全局异常处理
 * Created by 晶晶 on 2023/5/8.
 */
@ControllerAdvice
public class GlobalExceptionHandler {

    @ResponseBody
    @ExceptionHandler(value = ApiException.class)
    public ResponseReult handle(ApiException e) {
        if (e.getErrorCode() != null) {
            return ResponseReult.error(e.getErrorCode());
        }
        if (e.getError() != 0) {

            return ResponseReult.error(e.getError(), e.getMessage());
        }
        return ResponseReult.error(e.getMessage());
    }

    @ResponseBody
    @ExceptionHandler(value = SQLException.class)
    public ResponseReult handleValidException(SQLException e) {
        int errorCode = e.getErrorCode();
        String message = e.getMessage();
        return ResponseReult.error(errorCode, message);
    }

    @ResponseBody
    @ExceptionHandler(value = MethodArgumentNotValidException.class)
    public ResponseReult handleValidException(MethodArgumentNotValidException e) {
        BindingResult bindingResult = e.getBindingResult();
        String message = null;
        if (bindingResult.hasErrors()) {
            FieldError fieldError = bindingResult.getFieldError();
            if (fieldError != null) {
                message = fieldError.getField()+fieldError.getDefaultMessage();
            }
        }
        return ResponseReult.error(message);
    }
//
//    @ResponseBody
//    @ExceptionHandler(value = BindException.class)
//    public ResponseReult handleValidException(BindException e) {
//        BindingResult bindingResult = e.getBindingResult();
//        String message = null;
//        if (bindingResult.hasErrors()) {
//            FieldError fieldError = bindingResult.getFieldError();
//            if (fieldError != null) {
//                message = fieldError.getField()+fieldError.getDefaultMessage();
//            }
//        }
//        return ResponseReult.error(message);
//    }
}
