package com.shxy.xymanager_common.model;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.math.BigInteger;
import java.util.Date;
import java.util.List;

/**
 * 设备信息列表
 */
@Data
@ApiModel(value = "获取设备列表", description = "获取设备列表信息")
public class TerminalListModel implements Serializable {
    @ApiModelProperty(value = "总记录数", example = "120")
    private long total;
    @ApiModelProperty(value = "总页数", example = "120")
    private int totalpage;
    @ApiModelProperty(value = "当前页", example = "1")
    private int currentpage;
    @ApiModelProperty(value = "每页记录数", example = "1")
    private int pagesize;
    @ApiModelProperty(value = "设备信息列表", example = "[]")
    private List<TerminalsBean> list;

    @Data
    public static class TerminalsBean {

        @ApiModelProperty(value = "设备编号", example = "123456")
        private Integer id;

        @ApiModelProperty(value = "线路编号", example = "123456")
        private Integer lineId;

        @ApiModelProperty(value = "线路名称", example = "123456")
        private String lineName;

        @ApiModelProperty(value = "杆塔编号", example = "123456")
        private Integer towerId;

        @ApiModelProperty(value = "杆塔名称", example = "123456")
        private String towerName;

        @ApiModelProperty(value = "图像监测装置 ID（17 位编码）", example = "12345678")
        private String cmdId;

        @ApiModelProperty(value = "原始 ID，各厂家内部识别号", example = "12345678")
        private Short orgId;

        @ApiModelProperty(value = "装置名称", example = "名称名称")
        private String equipName;

        @ApiModelProperty(value = "显示名", example = "名称名称")
        private String displayName;

        @ApiModelProperty(value = "装置型号", example = "型号型号")
        private String model;

        @ApiModelProperty(value = "装置基本信息版本号", example = "型号型号")
        private String essentialInfoVersion;

        @ApiModelProperty(value = "是否带云台", example = " 0： 不带云台 1：带云台")
        private Byte hasPan;

        @ApiModelProperty(value = "生产厂家", example = "生产厂家")
        private String bsManufacturer;

        @ApiModelProperty(value = "生产日期", example = "2022-06-12")
        private Date bsProductionDate;

        @ApiModelProperty(value = "出厂编号", example = "123456")
        private String bsIdentifier;

        @ApiModelProperty(value = "纬度", example = "21321")
        private Double latitude;

        @ApiModelProperty(value = "经度", example = "213")
        private Double longitude;

        @ApiModelProperty(value = "4G信号强度", example = "213")
        private Short signalStrength4g;

        @ApiModelProperty(value = "装置上次启动时间", example = "213")
        private BigInteger bootTime;

        @ApiModelProperty(value = "电池电量", example = "213")
        private float batteryCapacity;

        @ApiModelProperty(value = "电源电压", example = "213")
        private float batteryVoltage;

        @ApiModelProperty(value = "最后一次心跳时间", example = "213")
        private BigInteger lastHeartbeat;

        @ApiModelProperty(value = "是否在线", example = "213")
        private boolean isonline;

        @ApiModelProperty(value = "是否删除", example = "0--删除1--未删除")
        private Integer status;

        @ApiModelProperty(value = "通道编号和名称", example = "213")
        private List<ChannelBeans> list;


    }

    @Data
    public static class ChannelBeans {
        @ApiModelProperty(value = "通道编号", example = "213")
        private Integer id;
        @ApiModelProperty(value = "通道名称", example = "213")
        private String name;
        @ApiModelProperty(value = "昵称", example = "213")
        private String alias;
    }


}
