package com.shxy.xymanager_common.util;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.date.DateField;
import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSONObject;
import com.shxy.xymanager_common.dto.PhotoTimeResultDto;
import com.shxy.xymanager_common.dto.ScheduleDetailsDto;
import com.shxy.xymanager_common.entity.ScheduleDetails;
import com.shxy.xymanager_common.model.TerminalScheduleRuleModel;
import com.shxy.xymanager_common.model.TerminalScheduleRuleTimeListModel;
import com.shxy.xymanager_common.vo.ScheduleRuleVo;
import net.sf.jsqlparser.expression.DateTimeLiteralExpression;

import java.math.BigDecimal;
import java.sql.Time;
import java.util.ArrayList;
import java.util.List;

/**
 * 拍照时间表工具类
 * jingjing
 */
public class ScheduleListUtils {
    /**
     * 将前端时间格式转换为湖南规约标准的数据库格式
     *
     * @param beans      规则列表
     * @param scheduleid 规则编号
     * @return
     */
    public static ArrayList<ScheduleDetails> getScheduleDetailsses(List<ScheduleRuleVo> beans, Integer scheduleid) {
        ArrayList<ScheduleDetails> list = new ArrayList<>();
        for (ScheduleRuleVo item : beans) {

            ScheduleDetails startrule = new ScheduleDetails();
            startrule.setScheduleId(scheduleid);
            Time startTime = item.getStartTime();
            startrule.setHour(MyDateUtils.hour(startTime, true));
            startrule.setMinute(MyDateUtils.minute(startTime));
            startrule.setPreset(255);
            list.add(startrule);

            ScheduleDetails endrule = new ScheduleDetails();
            endrule.setScheduleId(scheduleid);
            Time endTime = item.getEndTime();
            endrule.setHour(MyDateUtils.hour(endTime, true));
            endrule.setMinute(MyDateUtils.minute(endTime));
            endrule.setPreset(255);
            list.add(endrule);

            Integer span = item.getSpan();
            ScheduleDetails spanrule = new ScheduleDetails();
            spanrule.setScheduleId(scheduleid);
            spanrule.setHour(XyNumberUtils.delivery(span, 60));
            spanrule.setMinute(XyNumberUtils.remainder(span, 60));
            spanrule.setPreset(255);
            list.add(spanrule);

        }
        return list;
    }


    /**
     * 将前端时间格式转换为CMA时间表下发标准的字符串
     *
     * @param dtoList
     * @param offset
     * @return
     */
    public static String relateTime(List<ScheduleDetailsDto> dtoList, int offset) {
        StringBuffer timestr = new StringBuffer();
        short perset = dtoList.get(0).getPreset().shortValue();
        int index = 0;
        String startstring = "";
        String endstring = "";
        String spanstring = "";
        for (int i = 0; i < dtoList.size(); i++) {
            short startHour = 0;
            short startMin = 0;
            short endHour = 0;
            short endMin = 0;
            short spanHour = 0;
            short spanMin = 0;

            if (XyNumberUtils.remainder(i, 3) == 0) {
                index = i + 2;
                Number add = XyNumberUtils.add((Number) dtoList.get(i).getMinute(), offset);
                if (add.intValue() >= 60) {
                    Number add1 = XyNumberUtils.add((Number) dtoList.get(i).getHour(), 1);
                    if (add1.intValue() >= 24) {
                        startHour = Integer.valueOf(24).shortValue();
                        startMin = Integer.valueOf(0).shortValue();
                    } else {
                        startHour = XyNumberUtils.add((Number) dtoList.get(i).getHour(), 1).shortValue();
                        startMin = XyNumberUtils.sub(add, 60).shortValue();
                    }
                } else {
                    startHour = dtoList.get(i).getHour().shortValue();
                    startMin = add.shortValue();
                }
                startstring = " --hour" + index + "=" + startHour + " --min" + index + "=" + startMin + " --preset" + index + "=" + perset;
            } else if (XyNumberUtils.remainder(i, 3) == 1) {
                index = i + 2;
                Number add = XyNumberUtils.add((Number) dtoList.get(i).getMinute(), offset);
                if (add.intValue() >= 60) {
                    Number add1 = XyNumberUtils.add((Number) dtoList.get(i).getHour(), 1);
                    if (add1.intValue() >= 24) {
                        endHour = Integer.valueOf(24).shortValue();
                        endMin = Integer.valueOf(0).shortValue();
                    } else {
                        endHour = add1.shortValue();
                        endMin = XyNumberUtils.sub(add, 60).shortValue();
                    }
                } else {
                    endHour = dtoList.get(i).getHour().shortValue();
                    endMin = add.shortValue();
                }
                endstring = " --hour" + index + "=" + endHour + " --min" + index + "=" + endMin + " --preset" + index + "=" + perset;
            } else if (XyNumberUtils.remainder(i, 3) == 2) {
                index = i - 1;
                spanHour = dtoList.get(i).getHour().shortValue();
                spanMin = dtoList.get(i).getMinute().shortValue();
                spanstring = " --hour" + index + "=" + spanHour + " --min" + index + "=" + spanMin + " --preset" + index + "=" + perset;
                if (StrUtil.isNotEmpty(spanstring) && StrUtil.isNotEmpty(startstring) && StrUtil.isNotEmpty(endstring)) {
                    timestr.append(spanstring).append(startstring).append(endstring);
                }

            }
        }
        return timestr.toString();
    }


//    /**
//     * 将数据库标准转为前端的时间列表
//     *
//     * @param details
//     * @return
//     */
//    public static ArrayList<TerminalScheduleRuleModel.ScheduleRuleBean> getScheduleRuleBeans(List<ScheduleDetailsDto> details) {
//        ArrayList<TerminalScheduleRuleModel.ScheduleRuleBean> detailsBeans = new ArrayList<>();
//        for (int i = 0; i < details.size(); i++) {
//            TerminalScheduleRuleModel.ScheduleRuleBean scheduleDetailsBean = new TerminalScheduleRuleModel.ScheduleRuleBean();
//            if (XyNumberUtils.remainder(i, 3) == 0) {
//                Integer hour = details.get(i).getHour();
//                Integer minute = details.get(i).getMinute();
//                Time time = MyDateUtils.HHMMToTime(hour, minute);
//                scheduleDetailsBean.setStartTime(time);
//            } else if (XyNumberUtils.remainder(i, 3) == 1) {
//                Integer hour = details.get(i).getHour();
//                Integer minute = details.get(i).getMinute();
//                Time time = MyDateUtils.HHMMToTime(hour, minute);
//                scheduleDetailsBean.setEndTime(time);
//            } else if (XyNumberUtils.remainder(i, 3) == 2) {
//                Integer hour = details.get(i).getHour();
//                Integer minute = details.get(i).getMinute();
//                Number mul = XyNumberUtils.mul((Number) hour, 60);
//                Number add = XyNumberUtils.add(mul, minute);
//                scheduleDetailsBean.setSpan(add.intValue());
//            }
//            detailsBeans.add(scheduleDetailsBean);
//        }
//        return detailsBeans;
//    }

    /**
     * 将数据库标准转为前端时间列表为数组
     *
     * @param details
     * @return
     */
    public static ArrayList<TerminalScheduleRuleModel.ScheduleRuleBean> getScheduleDetailsBeans(List<ScheduleDetailsDto> details) {
        ArrayList<TerminalScheduleRuleModel.ScheduleRuleBean> detailsBeans = new ArrayList<>();
        TerminalScheduleRuleModel.ScheduleRuleBean scheduleDetailsBean = new TerminalScheduleRuleModel.ScheduleRuleBean();
        for (int i = 0; i < details.size(); i++) {
            ScheduleDetailsDto dto = details.get(i);
            if (XyNumberUtils.remainder(i, 3) == 0) {
                scheduleDetailsBean = new TerminalScheduleRuleModel.ScheduleRuleBean();
                Integer hour = dto.getHour();
                Integer minute = dto.getMinute();
                Time time = MyDateUtils.HHMMToTime(hour, minute);
                scheduleDetailsBean.setId(dto.getId());
                scheduleDetailsBean.setScheduleId(dto.getScheduleId());
                scheduleDetailsBean.setStartTime(time);
            } else if (XyNumberUtils.remainder(i, 3) == 1) {
                Integer hour = dto.getHour();
                Integer minute = dto.getMinute();
                Time time = MyDateUtils.HHMMToTime(hour, minute);
                scheduleDetailsBean.setEndTime(time);
            } else if (XyNumberUtils.remainder(i, 3) == 2) {
                Integer hour = dto.getHour();
                Integer minute = dto.getMinute();
                Number mul = XyNumberUtils.mul((Number) hour, 60);
                Number add = XyNumberUtils.add(mul, minute);
                scheduleDetailsBean.setSpan(add.intValue());
                detailsBeans.add(scheduleDetailsBean);
            }
        }
        return detailsBeans;
    }

    /*
     * 讲查询转为前端的时间字符串
     * */
    public static List<String> getResultDetails(List<PhotoTimeResultDto> resultDtoList) {
        List<String> resultList = new ArrayList<>();
        if (CollectionUtil.isNotEmpty(resultDtoList)) {
            DateTime starttime = null;
            Integer span = null;
            DateTime endtime;
            for (int j = 0; j < resultDtoList.size(); j++) {
                if (XyNumberUtils.remainder(j, 3) == 0) {//时间间隔
                    Integer hour = resultDtoList.get(j).getHour();
                    Integer minute = resultDtoList.get(j).getMinute();
                    Number mul = XyNumberUtils.mul((Number) hour, 60);
                    Number add = XyNumberUtils.add(mul, minute);
                    span = add.intValue();
                } else if (XyNumberUtils.remainder(j, 3) == 1) {//开始时间
                    Integer hour = resultDtoList.get(j).getHour();
                    Integer minute = resultDtoList.get(j).getMinute();
                    starttime = MyDateUtils.HHMMToDate(hour, minute);
                } else if (XyNumberUtils.remainder(j, 3) == 2) {//结束时间
                    Integer hour = resultDtoList.get(j).getHour();
                    Integer minute = resultDtoList.get(j).getMinute();
                    endtime = MyDateUtils.HHMMToDate(hour, minute);
                    if (starttime != null && endtime != null && span != null) {
                        List<DateTime> dateTimes = MyDateUtils.rangeToList(starttime, endtime, DateField.MINUTE, span);
                        for (DateTime data : dateTimes) {
                            String dateTime = DateUtil.formatTime(data);
                            resultList.add(dateTime);
                        }
                    }
                }
            }
        }
        return resultList;
    }

}
