package com.shxy.xymanager_common.vo;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import java.util.Date;
import java.util.List;

@Data
@ApiModel(value = "装置信息对象", description = "设备信息对象描述")
public class TerminalVo {
    @ApiModelProperty(value = "线路编号", example = "123456")
    private Integer lineId;

    @ApiModelProperty(value = "杆塔编号", example = "123456")
    private Integer towerId;

    @ApiModelProperty(value = "通道编号", example = "")
    private List<ChannelItem> list;

    @ApiModelProperty(value = "sim卡号", example = "123456")
    private String sim;

    @ApiModelProperty(value = "图像监测装置 ID（17 位编码）", example = "12345678")
    @NotBlank(message = "图像监测装置不能缺少")
    private String cmdId;

    @ApiModelProperty(value = "原始 ID，各厂家内部识别号", example = "12345678")
    private Short orgId;

    @ApiModelProperty(value = "装置名称", example = "名称名称")
    private String equipName;

    @ApiModelProperty(value = "显示名", example = "名称名称")
    private String displayName;

    @ApiModelProperty(value = "装置型号", example = "型号型号")
    private String model;

    @ApiModelProperty(value = "装置基本信息版本号", example = "型号型号")
    private String essentialInfoVersion;

    @ApiModelProperty(value = "是否带云台", example = " 0： 不带云台 1：带云台")
    private Byte hasPan;

    @ApiModelProperty(value = "生产厂家", example = "生产厂家")
    private String bsManufacturer;

    @ApiModelProperty(value = "生产日期", example = "2022-06-12")
    private Date bsProductionDate;

    @ApiModelProperty(value = "出厂编号", example = "123456")
    private String bsIdentifier;

    @ApiModelProperty(value = "纬度", example = "21321")
    private Double latitude;

    @ApiModelProperty(value = "经度", example = "213")
    private Double longitude;

    @Data
    public static class ChannelItem {
        @NotNull(message = "通道编号")
        @ApiModelProperty(value = "装置编号", example = "123455")
        private Integer id;

        @ApiModelProperty(value = "别名", example = "123455")
        private String alias;
    }
}
