package com.shxy.xymanager_dao.dao;

import cn.hutool.core.util.StrUtil;
import com.shxy.xymanager_common.bean.SysUser;
import com.shxy.xymanager_common.entity.SysUserSession;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.Date;
import java.util.List;

/**
 * @ClassName：SysUserMapper
 * @Description： 用户表 Mapper 接口.
 * @Author： Arno_Fu
 * @CreatTime：11/26/2019 - 2:51 PM
 * @Version V1.0
 */

@Mapper
public interface SysUserMapperDao {

    /**
     * @param userAccount
     * @return com.chenxuan.entity.model.SysUser
     * @Description 通过用户账户获取用户信息
     */
    SysUser selectByUserAccount(@Param("userName") String userAccount);


    /**
     * 校验用户名称是否唯一
     *
     * @param userName 用户名称
     * @return 结果
     */
    int checkUserNameUnique(@Param("userName") String userName);


    int addUser(SysUser user);

    Integer updateById(SysUser user);


    /**
     * 通过用户名查询用户
     *
     * @param userName 用户名
     * @return 用户对象信息
     */
    public SysUser selectUserByUserName(String userName);

    /**
     * 通过用户ID查询用户
     *
     * @param userId 用户ID
     * @return 用户对象信息
     */
    public SysUser selectUserById(Long userId);


    /**
     * 修改用户头像
     *
     * @param userName 用户名
     * @param avatar   头像地址
     * @return 结果
     */
    int updateUserAvatar(@Param("userName") String userName, @Param("avatar") String avatar);

    /**
     * 重置用户密码
     *
     * @param userName 用户名
     * @param password 密码
     * @return 结果
     */
    int resetUserPwd(@Param("userName") String userName, @Param("password") String password);


    /**
     * 批量删除用户信息
     *
     * @param userIds 需要删除的用户ID
     * @return 结果
     */
    public int deleteUserByIds(Long[] userIds);


    int deleteUserById(String userId);


    SysUserSession selectUserBySessionId(String sessionId);

    void insertUserSession(SysUserSession session);

    int updateUserSession(SysUserSession session);

    List<SysUser> selectUserInfoList(@Param("status") Integer status);

    int insertOrUpdate(@Param("item") SysUserSession session, @Param("createat") Date create, @Param("updateat") Date update);

    SysUserSession selectBySessionId(@Param("sessionid") String sessionid);


}
