package com.shxy.xymanager_framework.interaction;


import cn.hutool.core.date.DateTime;
import cn.hutool.core.util.NumberUtil;
import cn.hutool.core.util.StrUtil;
import com.shxy.xymanager_common.annotation.JwtIgnore;
import com.shxy.xymanager_common.entity.SysUserSession;
import com.shxy.xymanager_common.enums.HttpMethod;
import com.shxy.xymanager_common.exception.Asserts;
import com.shxy.xymanager_common.util.MyDateUtils;
import com.shxy.xymanager_service.service.SysUserService;
import javafx.beans.binding.NumberBinding;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;
import org.springframework.web.method.HandlerMethod;
import org.springframework.web.servlet.HandlerInterceptor;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.math.BigInteger;

/**
 * @ClassName：JwtAuthenticationTokenFilter
 * @Description： token过滤器 验证token有效性.
 * @Author： Arno_Fu
 * @CreatTime：11/26/2019 - 6:34 PM
 * @Version V1.0
 */
@Component
@Slf4j
public class JwtInterceptor implements HandlerInterceptor {

    @Autowired
    SysUserService sysUserService;

    @Value("${session.expire_time}")
    public BigInteger time;

    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) throws Exception {
        // 忽略带JwtIgnore注解的请求, 不做后续token认证校验
        if (handler instanceof HandlerMethod) {
            HandlerMethod handlerMethod = (HandlerMethod) handler;
            JwtIgnore jwtIgnore = handlerMethod.getMethodAnnotation(JwtIgnore.class);
            if (jwtIgnore != null) {
                return true;
            }
        }
        if (HttpMethod.GET.name().equals(request.getMethod())) {
            response.setStatus(HttpServletResponse.SC_OK);
            return true;
        }
        // 获取请求头信息authorization信息
        final String sessionId = request.getHeader("sessionId");
        if (StrUtil.isBlank(sessionId)) {
            log.info("sessionId为空登录过期");
            Asserts.fail(401, "登录过期");
        } else {
            SysUserSession user = sysUserService.selectUserById(sessionId);
            if (user != null) {
                BigInteger expireTime = user.getExpireTime();

                long currentTime = MyDateUtils.TimeMillSecond2Second(new DateTime());
                if ((currentTime - expireTime.longValue()) > time.longValue()) {
                    user.setExpireTime(BigInteger.valueOf(currentTime).add(time));
                    sysUserService.updateUserSession(user);
                }
            } else {
                log.info("sessionId为空登录过期");
                Asserts.fail(401, "登录过期");
            }
        }

        return true;
    }

    @Override
    public void postHandle(HttpServletRequest request, HttpServletResponse response, Object handler, ModelAndView modelAndView) throws Exception {
        HandlerInterceptor.super.postHandle(request, response, handler, modelAndView);
    }

    @Override
    public void afterCompletion(HttpServletRequest request, HttpServletResponse response, Object handler, Exception ex) throws Exception {
        HandlerInterceptor.super.afterCompletion(request, response, handler, ex);
    }


   /* @Override
    protected void doFilterInternal(HttpServletRequest request, HttpServletResponse response, FilterChain chain) throws ServletException, IOException {
        UserSession user = null;
        if(null!= request.getSession().getAttribute("sessionId")) {
            String sessionId = request.getSession().getAttribute("sessionId").toString();
            user = sysUserService.selectUserById(sessionId);
            BigInteger expireTime = user.getExpireTime();

            BigInteger currentTime = MyDateUtils.TimeSecond2MillSecond(System.currentTimeMillis());
            if (expireTime.subtract(currentTime).compareTo(BigInteger.valueOf(3600L)) > 0) {
                user.setExpireTime(user.getExpireTime().add(new BigInteger(String.valueOf(30 * 1800))));
                sysUserService.updateUserSession(user);
            }
        }*/




      /*  if (null != user && null == SecurityUtils.getAuthentication())
        {

            UsernamePasswordAuthenticationToken authenticationToken = new UsernamePasswordAuthenticationToken(user, null,null);
            authenticationToken.setDetails(new WebAuthenticationDetailsSource().buildDetails(request));
            SecurityContextHolder.getContext().setAuthentication(authenticationToken);
        }

        chain.doFilter(request, response);
    }*/
}
