package com.shxy.xymanager_service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.bean.copier.CopyOptions;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUnit;
import com.shxy.xymanager_common.bean.ServiceBody;
import com.shxy.xymanager_common.dto.DyLineAndTerminalWithHeartDto;
import com.shxy.xymanager_common.entity.DyLevel;
import com.shxy.xymanager_common.dto.TerminalsWithHeart;
import com.shxy.xymanager_common.enums.CommonStatus;
import com.shxy.xymanager_common.exception.Asserts;
import com.shxy.xymanager_common.model.DyLineTreeListModel;
import com.shxy.xymanager_common.model.DyListModel;
import com.shxy.xymanager_common.util.MyDateUtils;
import com.shxy.xymanager_common.util.TerminalUtils;
import com.shxy.xymanager_common.vo.TestVo;
import com.shxy.xymanager_dao.dao.DyLevelDao;
import com.shxy.xymanager_service.service.DyLevelService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.math.BigInteger;
import java.util.ArrayList;
import java.util.List;

/**
 * 装置通道实现层
 */
@Service
@Slf4j
public class DyLevelServiceImpl implements DyLevelService {

    @Autowired
    DyLevelDao dyLevelDao;

    /**
     * 获取电压线路树状接口
     *
     * @return
     */
    @Override
    public ServiceBody<DyLineTreeListModel> getdyTreeList() {
        DyLineTreeListModel model = new DyLineTreeListModel();
        List<DyLineAndTerminalWithHeartDto> list = dyLevelDao.selectTreeList(CommonStatus.EFFECTIVE.value());
        boolean empty = CollectionUtil.isEmpty(list);
        if (empty) {
            model.setList(new ArrayList<>());
        } else {
            List<DyLineTreeListModel.DyListBean> beans = BeanUtil.copyToList(list, DyLineTreeListModel.DyListBean.class, CopyOptions.create().ignoreCase());
            for (int i = 0; i < beans.size(); i++) {
                for (int j = 0; j < beans.get(i).getList().size(); j++) {
                    for (int k = 0; k < beans.get(i).getList().get(j).getList().size(); k++) {
                        TerminalsWithHeart terminalsWithHeart = list.get(i).getList().get(j).getList().get(k);
                        BigInteger lastheartbeat = terminalsWithHeart.getLastheartbeat();
                        boolean b = TerminalUtils.judgeTerminalStatus(lastheartbeat);
                        if (b) {
                            beans.get(i).getList().get(j).getList().get(k).setOnlinestatus(CommonStatus.EFFECTIVE.value());
                        } else {
                            beans.get(i).getList().get(j).getList().get(k).setOnlinestatus(CommonStatus.DELETE.value());
                        }
                    }
                }
            }
            model.setList(beans);
        }
        return Asserts.success(model);
    }


    /**
     * 获取电压等级列表
     *
     * @return
     */
    @Override
    public ServiceBody<DyListModel> getdyList() {
        DyListModel model = new DyListModel();
        List<DyLevel> list = dyLevelDao.selectAll(CommonStatus.EFFECTIVE.value());
        boolean empty = CollectionUtil.isEmpty(list);
        if (empty) {
            model.setList(new ArrayList<>());
        } else {
            List<DyListModel.DyBean> models = BeanUtil.copyToList(list, DyListModel.DyBean.class);
            model.setList(models);
        }
        return Asserts.success(model);
    }

    @Override
    public ServiceBody<String> gettest(List<TestVo> vo) {
        log.info(vo.toString());
        return Asserts.success("success");
    }
}
