package com.shxy.xymanager_service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.bean.copier.CopyOptions;
import cn.hutool.core.collection.CollectionUtil;
import com.github.pagehelper.PageInfo;
import com.shxy.xymanager_common.bean.ServiceBody;
import com.shxy.xymanager_common.dto.LineAndDyNameDto;
import com.shxy.xymanager_common.dto.TermChannelAndMapperDto;
import com.shxy.xymanager_common.entity.DyLevel;
import com.shxy.xymanager_common.entity.Lines;
import com.shxy.xymanager_common.entity.Terminals;
import com.shxy.xymanager_common.entity.Towers;
import com.shxy.xymanager_common.enums.CommonStatus;
import com.shxy.xymanager_common.exception.Asserts;
import com.shxy.xymanager_common.model.LineAndGtAndChannelListModel;
import com.shxy.xymanager_common.model.LineListModel;
import com.shxy.xymanager_common.page.PageUtils;
import com.shxy.xymanager_common.vo.*;
import com.shxy.xymanager_dao.dao.*;
import com.shxy.xymanager_service.service.CacheService;
import com.shxy.xymanager_service.service.LineService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 线路服务实现层
 *
 * @author 晶晶
 */
@Slf4j
@Service
public class LineServiceImpl implements LineService {

    @Autowired
    private LinesDao linesDao;

    @Autowired
    private DyLevelDao dyLevelDao;

    @Autowired
    private TowerDao towerDao;

    @Autowired
    private TerminalsDao terminalsDao;

    @Autowired
    private TerminalChannelsDao terminalChannelsDao;

    @Autowired
    private CacheService cacheService;

    /**
     * 获取线路
     *
     * @return
     */
    @Override
    public ServiceBody<LineListModel> getLineList(PageVo vo) {
        LineListModel model = new LineListModel();
        int pageindex = vo.getPageindex();
        int pagesize = vo.getPagesize();
        PageUtils.SetPage(pageindex, pagesize);
        List<LineAndDyNameDto> list = linesDao.selectAll(CommonStatus.EFFECTIVE.value());
        boolean empty = CollectionUtil.isEmpty(list);
        if (empty) {
            model.setList(new ArrayList<>());
        } else {
            List<LineListModel.LineBean> beans = BeanUtil.copyToList(list, LineListModel.LineBean.class, CopyOptions.create().ignoreCase());
            model.setList(beans);
        }
        PageInfo pageData = PageUtils.getPageData(list);
        int currentpage = pageData.getPageNum();
        model.setCurrentpage(currentpage);
        long total = pageData.getTotal();
        model.setTotal(total);

        int pageSize = pageData.getPageSize();
        model.setPagesize(pageSize);
        int pages = pageData.getPages();
        model.setTotalpage(pages);


        return Asserts.success(model);
    }

    /**
     * 添加线路
     *
     * @param vo
     * @return
     */
    @Override
    public ServiceBody<String> addLine(LineVo vo) {
        List<Lines> lines = BeanUtil.copyToList(vo.getList(), Lines.class, CopyOptions.create().ignoreCase());
        Date date = new Date();
        int i = linesDao.insertList(lines, CommonStatus.EFFECTIVE.value(), date, date);
        if (i != 0) {
            cacheService.updateLineMap();
            return Asserts.success("录入成功");
        } else {
            return Asserts.error("录入失败");
        }
    }

    /**
     * 删除线路
     *
     * @param vo
     * @return
     */
    @Override
    public ServiceBody<String> deleteLine(LineIdVo vo) {
        List<Lines> lines = BeanUtil.copyToList(vo.getList(), Lines.class);
        Date date = new Date();
        int i = linesDao.deleteById(lines, CommonStatus.DELETE.value(), date);
        if (i != 0) {
            cacheService.updateLineMap();
            return Asserts.success("删除成功");
        } else {
            return Asserts.error("删除失败");
        }
    }


    /**
     * 修改线路
     *
     * @param vo
     * @return
     */
    @Override
    public ServiceBody<String> updateLine(UpdateLineVo vo) {
        Lines lines = new Lines();
        BeanUtil.copyProperties(vo, lines, true);
        int i = linesDao.updateByPrimaryKeySelective(lines, new Date());
        if (i != 0) {
            cacheService.updateLineMap();
            return Asserts.success("修改成功");
        } else {
            return Asserts.error("修改失败");
        }
    }

    /**
     * 电压线路杆塔
     *
     * @param vo
     * @return
     */
    @Override
    public ServiceBody<LineAndGtAndChannelListModel> getLineAndGt(LineAndGtAndChannelVo vo) {
        LineAndGtAndChannelListModel model = new LineAndGtAndChannelListModel();
        Integer id = vo.getId();
        Integer type = vo.getType();
        if (id != null && id.intValue() == 0) {
            id = null;
        }
        List<LineAndGtAndChannelListModel.Bean> beans = new ArrayList<>();
        //查询所有
        if (type == 1) {
            List<DyLevel> list = dyLevelDao.selectAll(CommonStatus.EFFECTIVE.value());
            beans = BeanUtil.copyToList(list, LineAndGtAndChannelListModel.Bean.class);
        } else if (type == 2) {
            if (id != null) {
                List<Lines> list = linesDao.selectLineByDyId(id, CommonStatus.EFFECTIVE.value());
                beans = BeanUtil.copyToList(list, LineAndGtAndChannelListModel.Bean.class);
            }
        } else if (type == 3) {
            if (id != null) {
                List<Towers> list = towerDao.selectAllByLineid(id, CommonStatus.EFFECTIVE.value());
                beans = BeanUtil.copyToList(list, LineAndGtAndChannelListModel.Bean.class);
            }
        } else if (type == 4) {
            if (id != null) {
                List<Terminals> list = terminalsDao.selectByTowerId(id, CommonStatus.EFFECTIVE.value());
                for (Terminals item : list) {
                    LineAndGtAndChannelListModel.Bean bean = new LineAndGtAndChannelListModel.Bean();
                    bean.setId(item.getId());
                    bean.setName(item.getDisplayName());
                    beans.add(bean);
                }
            }
        } else if (type == 5) {
            if (id != null) {
                List<TermChannelAndMapperDto> list = terminalChannelsDao.selectByTermid(id, CommonStatus.EFFECTIVE.value());
                for (TermChannelAndMapperDto item : list) {
                    LineAndGtAndChannelListModel.Bean bean = new LineAndGtAndChannelListModel.Bean();
                    bean.setId(item.getChannelid());
                    bean.setAlias(item.getAlias());
                    bean.setName(item.getChannelname());
                    beans.add(bean);
                }
            }
        }
        model.setList(beans);
        return Asserts.success(model);
    }

    /**
     * 线路杆塔查询
     *
     * @param vo
     * @return
     */
    @Override
    public ServiceBody<LineAndGtAndChannelListModel> getLineAndGtList(LineAndGtVo vo) {
        LineAndGtAndChannelListModel model = new LineAndGtAndChannelListModel();
        List<LineAndGtAndChannelListModel.Bean> beans = new ArrayList<>();
        Integer type = vo.getType();
        Integer id = vo.getId();
        if (type.intValue() == 1) {
            List<Lines> list = linesDao.selectLineByDyId(null, CommonStatus.EFFECTIVE.value());
            beans = BeanUtil.copyToList(list, LineAndGtAndChannelListModel.Bean.class);
        } else {
            if (id != null) {
                List<Towers> list = towerDao.selectAllByLineid(id, CommonStatus.EFFECTIVE.value());
                beans = BeanUtil.copyToList(list, LineAndGtAndChannelListModel.Bean.class);
            }
        }
        model.setList(beans);
        return Asserts.success(model);
    }

}

