package com.shxy.xymanager_service.impl;

import cn.hutool.core.date.DateTime;
import com.shxy.xymanager_common.bean.ServiceBody;
import com.shxy.xymanager_common.bean.SysUser;
import com.shxy.xymanager_common.config.CustomRsaProperties;
import com.shxy.xymanager_common.constant.HttpStatusCode;
import com.shxy.xymanager_common.constant.UuidUtils;
import com.shxy.xymanager_common.entity.SysUserSession;
import com.shxy.xymanager_common.exception.Asserts;
import com.shxy.xymanager_common.exception.UserPasswordNotMatchException;
import com.shxy.xymanager_common.util.MyDateUtils;
import com.shxy.xymanager_common.util.RsaUtils;
import com.shxy.xymanager_common.util.StringUtils;
import com.shxy.xymanager_dao.dao.SysUserMapperDao;
import com.shxy.xymanager_service.service.LoginService;
import com.shxy.xymanager_service.service.SysUserService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigInteger;
import java.util.Date;

/**
 * 装置通道实现层
 */
@Service
@Slf4j
public class LoginServiceImpl implements LoginService {


    @Autowired
    private SysUserService sysUserService;

    @Autowired
    private SysUserMapperDao sysUserMapperDao;

    /**
     *
     * @param sysUser
     * @return
     */
    public ServiceBody<SysUserSession> remoteLogin(SysUser sysUser)  {
        String sessionId = UuidUtils.getUUID();
        try {
            SysUserSession user = getLoginUser(sysUser);
            user.setSessionId(sessionId);
//            sysUserMapperDao.insertUserSession(user);
            Date date = new Date();
            sysUserMapperDao.insertOrUpdate(user, date,date);
            return Asserts.success(user);
        } catch (UserPasswordNotMatchException e){
            return Asserts.error(e.getMessage());
        } catch (Exception e) {
           log.error("登录异常:{}",e.getMessage());
        }
        return Asserts.error("登录失败");
    }

    /**
     * 用户登录校验
     *
     * @param sysUser
     * @return
     */
    public SysUserSession getLoginUser(SysUser sysUser) throws Exception {
        // 用户验证
        SysUser account = sysUserService.findByUserAccount(sysUser.getUserName());
        // 判断用户是否存在
        if (StringUtils.isNull(account)) {
            throw new UserPasswordNotMatchException("用户不存在", HttpStatusCode.ERROR);
        }
        // 密码解密
        String pwd = RsaUtils.decryptByPrivateKey( CustomRsaProperties.privateKey, account.getPassword() );
        // 密码对比
        if (!sysUser.getPassword().equals(pwd)) {
            throw new UserPasswordNotMatchException("密码错误", HttpStatusCode.ERROR);
        }
        SysUserSession user = new SysUserSession();
//        loginUser.setPermissions(permissions);
        user.setUserName(sysUser.getUserName());
        user.setRole(account.getRole());
        long date = MyDateUtils.TimeMillSecond2Second(new DateTime());
        user.setExpireTime(BigInteger.valueOf(date));
        user.setId(account.getUserId());
        return user;
    }
}
