package com.shxy.xymanager_service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUnit;
import cn.hutool.core.util.StrUtil;
import cn.hutool.crypto.SecureUtil;
import cn.hutool.json.JSONObject;
import com.shxy.xymanager_common.constant.UuidUtils;
import com.shxy.xymanager_common.dto.TerminalsWithHeart;
import com.shxy.xymanager_common.entity.SysUser;
import com.shxy.xymanager_common.entity.SysUserSession;
import com.shxy.xymanager_common.entity.Terminals;
import com.shxy.xymanager_common.enums.CommonStatus;
import com.shxy.xymanager_common.util.CmaUtil;
import com.shxy.xymanager_common.util.MyDateUtils;
import com.shxy.xymanager_common.util.ProcessExecUtils;
import com.shxy.xymanager_common.util.TerminalUtils;
import com.shxy.xymanager_common.vo.OpenCmdidVo;
import com.shxy.xymanager_common.vo.OpenDeviceCaptureVo;
import com.shxy.xymanager_common.vo.UserLoginVo;
import com.shxy.xymanager_dao.dao.SysUserDao;
import com.shxy.xymanager_dao.dao.SysUserMapperDao;
import com.shxy.xymanager_dao.dao.TerminalStatusDao;
import com.shxy.xymanager_dao.dao.TerminalsDao;
import com.shxy.xymanager_service.service.OpenService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;
import org.springframework.stereotype.Service;

import java.math.BigInteger;
import java.util.Date;

/**
 * 第三方对外接口
 */
@Service
@Component
@Slf4j
public class OpenServiceImpl implements OpenService {
    @Autowired
    private SysUserMapperDao sysUserMapperDao;

    @Autowired
    private SysUserDao sysUserDao;

    @Autowired
    private TerminalsDao terminalsDao;

    @Autowired
    private TerminalStatusDao terminalStatusDao;


    @Value("${session.open_expire_time}")
    public Integer time;

    /**
     * 登录鉴权
     *
     * @param vo
     * @return
     */
    @Override
    public JSONObject cmaUserLogin(UserLoginVo vo) {
        JSONObject jsonObject = new JSONObject();
        String username = vo.getUserName();
        String userPassword = vo.getPassWord();
        SysUser sysUser = sysUserDao.selectByUserName(username);
        // 判断用户是否存在
        if (BeanUtil.isEmpty(sysUser)) {
            jsonObject.putOpt("errcode", 1);
            jsonObject.putOpt("errmsg", "用户不存在");
            return jsonObject;
        }
        // 判断密码是否存在
        String password = vo.getPassWord();
        if (BeanUtil.isEmpty(password)) {
            jsonObject.putOpt("errcode", 2);
            jsonObject.putOpt("errmsg", "密码错误");
            return jsonObject;
        }
        // 密码对比
        if (!sysUser.getPassword().equals(userPassword)) {
            jsonObject.putOpt("errcode", 2);
            jsonObject.putOpt("errmsg", "密码错误");
            return jsonObject;
        }

        Date date = new Date();
        String sessionId = UuidUtils.getUUID();
        SysUserSession sysUserSession = new SysUserSession();
        sysUserSession.setUserName(username);
        sysUserSession.setRole(sysUser.getRole());
        sysUserSession.setSessionId(sessionId);
        long expiretime = MyDateUtils.TimeMillSecond2Second(MyDateUtils.offsetMinute(date, time));
        sysUserSession.setExpireTime(BigInteger.valueOf(expiretime));
        sysUserMapperDao.insertOrUpdate(sysUserSession, date, date);
        jsonObject.set("errcode", 0);
        jsonObject.set("errmsg", "OK");
        jsonObject.set("sessionid", sessionId);
        jsonObject.set("keepingtime", time);

        return jsonObject;
    }

    /**
     * 控制拍照视频
     *
     * @param vo
     * @return
     */
    @Override
    public JSONObject ctrlCmaDeviceCapture(OpenDeviceCaptureVo vo) {
        JSONObject jsonObject = new JSONObject();
        String sessionID = vo.getSessionID();
        String deviceID = vo.getDeviceID();
        Integer operateType = vo.getOperateType();
        if (StrUtil.isEmpty(sessionID)) {
            jsonObject.set("errcode", 1);
            jsonObject.set("errmsg", "invalid session");
            return jsonObject;
        }
        if (StrUtil.isEmpty(deviceID)) {
            jsonObject.set("errcode", 2);
            jsonObject.set("errmsg", "device not register");
            return jsonObject;
        }

        SysUserSession sysUserSession = sysUserMapperDao.selectBySessionId(sessionID);
        if (BeanUtil.isEmpty(sysUserSession)) {
            jsonObject.set("errcode", 1);
            jsonObject.set("errmsg", "invalid session");
            return jsonObject;
        } else {
            BigInteger expireTime = sysUserSession.getExpireTime();
            long currentTime = MyDateUtils.TimeMillSecond2Second(new DateTime());
            if ((currentTime - expireTime.longValue()) > time.longValue()) {
                jsonObject.set("errcode", 1);
                jsonObject.set("errmsg", "invalid session");
                return jsonObject;
            }
        }

        Terminals terminals = terminalsDao.selectByCmdid(deviceID, CommonStatus.EFFECTIVE.value());
        if (BeanUtil.isEmpty(terminals)) {
            jsonObject.set("errcode", 2);
            jsonObject.set("errmsg", "device not register");
            return jsonObject;
        }

        if (operateType == 1) {
            operateType = 0;
        } else if (operateType == 2) {
            operateType = 1;
        } else {
            jsonObject.set("errcode", 3);
            jsonObject.set("errmsg", "invalid protocol");
            return jsonObject;
        }

        String cmd1 = CmaUtil.takePic(vo.getDeviceID(), 1, operateType);
        ProcessExecUtils.exec(cmd1);
        String cmd2 = CmaUtil.takePic(vo.getDeviceID(), 2, operateType);
        ProcessExecUtils.exec(cmd2);
        jsonObject.set("errcode", 0);
        jsonObject.set("errmsg", "OK");

        return jsonObject;
    }

    /**
     * 查询设备在线状态
     *
     * @param vo
     * @return
     */
    @Override
    public JSONObject cmaDeviceStatus(OpenCmdidVo vo) {
        JSONObject jsonObject = new JSONObject();
        String sessionID = vo.getSessionID();
        String deviceID = vo.getDeviceID();
        if (StrUtil.isEmpty(sessionID)) {
            jsonObject.set("errcode", 1);
            jsonObject.set("errmsg", "invalid session");
            return jsonObject;
        }
        SysUserSession sysUserSession = sysUserMapperDao.selectBySessionId(sessionID);
        if (BeanUtil.isEmpty(sysUserSession)) {
            jsonObject.set("errcode", 1);
            jsonObject.set("errmsg", "invalid session");
            return jsonObject;
        } else {
            BigInteger expireTime = sysUserSession.getExpireTime();
            long currentTime = MyDateUtils.TimeMillSecond2Second(new DateTime());
            if ((currentTime - expireTime.longValue()) > time.longValue()) {
                jsonObject.set("errcode", 1);
                jsonObject.set("errmsg", "invalid session");
                return jsonObject;
            }
        }
        if (StrUtil.isEmpty(deviceID)) {
            jsonObject.set("errcode", 2);
            jsonObject.set("errmsg", "device not register");
            return jsonObject;
        }
        TerminalsWithHeart terminalsWithHeart = terminalStatusDao.selectByCmdId(deviceID);
        if (BeanUtil.isEmpty(terminalsWithHeart)) {
            jsonObject.set("errcode", 2);
            jsonObject.set("errmsg", "device not register");
            return jsonObject;
        }
        BigInteger lastheartbeat = terminalsWithHeart.getLastheartbeat();
        boolean b = TerminalUtils.judgeTerminalStatus(lastheartbeat);
        if (b) {
            jsonObject.set("isonline", true);
            jsonObject.set("errcode", 0);
            jsonObject.set("errmsg", "ok");
        } else {
            jsonObject.set("isonline", false);
            jsonObject.set("errcode", 0);
            jsonObject.set("errmsg", "ok");
        }

        return jsonObject;
    }
}
