package com.shxy.xymanager_service.impl;


import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.bean.copier.CopyOptions;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.date.DateTime;
import com.github.pagehelper.PageInfo;
import com.shxy.xymanager_common.bean.ServiceBody;
import com.shxy.xymanager_common.bean.SysUser;
import com.shxy.xymanager_common.config.CustomRsaProperties;
import com.shxy.xymanager_common.entity.SysUserSession;
import com.shxy.xymanager_common.enums.CommonStatus;
import com.shxy.xymanager_common.exception.Asserts;
import com.shxy.xymanager_common.model.SysUserModel;
import com.shxy.xymanager_common.page.PageUtils;
import com.shxy.xymanager_common.util.RsaUtils;
import com.shxy.xymanager_common.util.StringUtils;
import com.shxy.xymanager_common.vo.PageVo;
import com.shxy.xymanager_common.vo.SysUserUpdateVo;
import com.shxy.xymanager_common.vo.SysUserVo;
import com.shxy.xymanager_dao.dao.SysUserMapperDao;
import com.shxy.xymanager_service.service.SysUserService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Component;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestBody;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


/**
 * @ClassName：SysUserServiceImpl
 * @Description： * 用户信息表 服务实现类.
 * @Author： Arno_Fu
 * @CreatTime：11/26/2019 - 3:26 PM
 * @Version V1.0
 */
@Service
@Component
@Slf4j
public class SysUserServiceImpl  implements SysUserService {

    @Autowired
    private SysUserMapperDao sysUserMapperDao;

    @Override
    public SysUser findByUserAccount(String userAccount) {
        return sysUserMapperDao.selectByUserAccount(userAccount);
    }

    @Override
    public Boolean checkUserNameUnique(String userName) {
        return sysUserMapperDao.checkUserNameUnique(userName) > 0 ? false : true;
    }

    @Override
    public Integer insertUser(SysUser user) {
        int flag = sysUserMapperDao.addUser(user);
        if(flag>0)
        {
            Map<String, Object> map = new HashMap<>();
            map.put("userName",user.getUserName());
            map.put("password",user.getPassword());
            addUserRemote(map);
            return flag;
        }
        return flag;
    }

    @Override
    public SysUser selectUserById(Long userId) {
        return sysUserMapperDao.selectUserById(userId);
    }

    @Override
    public ServiceBody<String> addUser(SysUserVo vo) {
        if (!this.checkUserNameUnique(vo.getUserName())) {
            return Asserts.error("新增用户'" +vo.getUserName() + "'失败，登录账号已存在");
        }
        SysUser sysUser = new SysUser();
        String userName = vo.getUserName();
        String nickName= userName;
        sysUser.setUserName(userName);
        sysUser.setNickName(nickName);
        sysUser.setCreateTime(new DateTime());
        sysUser.setRole(vo.getRole());
        try {
            sysUser.setPassword(RsaUtils.encryptByPublicKey( CustomRsaProperties.publicKey,vo.getPassword()));
        } catch (Exception e) {
           log.error("密码转码失败:{}",e.getMessage());
        }
        this.insertUser(sysUser);
        return Asserts.success("新增成功");
    }

    @Override
    public void checkUserAllowed(SysUser user) {

    }

    @Override
    public  ServiceBody<String> updateUser(SysUserUpdateVo vo) {
        SysUser user = new SysUser();
        BeanUtils.copyProperties(vo,user);
        try {
            if(StringUtils.isNotBlank( user.getPassword())) {
                user.setPassword(RsaUtils.encryptByPublicKey(CustomRsaProperties.publicKey, vo.getPassword()));
            }
        } catch (Exception e) {
            log.error("修改密码异常:{}",e.getMessage());
        }
        int result = sysUserMapperDao.updateById(user);
        if(result>0){
            return Asserts.success("修改成功");
        }
        return Asserts.error("修改失败");


    }

    @Override
    public Boolean updateUserStatus(SysUser user) {
        return null;
    }

    @Override
    public Boolean updateUserProfile(SysUser user) {
        return null;
    }

    @Override
    public Boolean resetPwd(SysUser user) {
        return null;
    }

    @Override
    public Boolean resetUserPwd(String userName, String password) {
        int count = sysUserMapperDao.resetUserPwd(userName, password);
        return count > 0 ? true : false;
    }

    @Override
    public ServiceBody<String> deleteUserById(String userId) {

        int result = sysUserMapperDao.deleteUserById(userId);
        if(result>0){
            return  Asserts.success("删除成功");
        }
        return Asserts.error("失败");
    }


    @Override
    public SysUserSession selectUserById(String sessionId) {
        SysUserSession session = sysUserMapperDao.selectUserBySessionId(sessionId);
        return session;
    }

    @Override
    public int updateUserSession(SysUserSession user) {
        int result = sysUserMapperDao.updateUserSession(user);
        return result;
    }

    @Override
    public ServiceBody<SysUserModel> selectUserList(@RequestBody @Validated PageVo vo) {
        SysUserModel model = new SysUserModel();
        int pageindex = vo.getPageindex();
        int pagesize = vo.getPagesize();
        PageUtils.SetPage(pageindex, pagesize);
        List<SysUser> list = sysUserMapperDao.selectUserInfoList(CommonStatus.EFFECTIVE.value());

        boolean empty = CollectionUtil.isEmpty(list);
        if (empty) {
            model.setList(new ArrayList<>());
        } else {
            List<SysUserModel.SysUserBean> beans = BeanUtil.copyToList(list,SysUserModel.SysUserBean.class, CopyOptions.create().ignoreCase());

//            BeanUtil.copyToList()
//            List<SysUserModel.SysUserBean> beans = Lists.newArrayList();
//            list.forEach(var->{
//                SysUserModel.SysUserBean bean = new SysUserModel.SysUserBean();
//                BeanUtils.copyProperties(var,bean);
//                bean.setCreateTime(var.getCreateTime());
//                beans.add(bean);
//            });
            model.setList(beans);
        }
        PageInfo pageData = PageUtils.getPageData(list);
        int currentpage = pageData.getPageNum();
        model.setCurrentpage(currentpage);
        long total = pageData.getTotal();
        model.setTotal(total);

        int pageSize = pageData.getPageSize();
        model.setPagesize(pageSize);
        int pages = pageData.getPages();
        model.setTotalpage(pages);
        return Asserts.success(model);
    }

    public boolean addUserRemote(Map<String, Object> map) {
        HttpHeaders httpHeaders = new HttpHeaders();
        httpHeaders.setContentType(MediaType.parseMediaType(MediaType.APPLICATION_JSON_UTF8_VALUE));
        HttpEntity<Map<String, Object>> httpEntity = new HttpEntity<>(map, httpHeaders);
        /*ResponseEntity responseEntity = restTemplate.postForEntity(remoteUserAdd, httpEntity,
                Object.class);
        int code = responseEntity.getStatusCodeValue();*/
        int code = 200;
        if(code ==200)
        {
            return true;
        }
        return false;
    }
}
