package com.shxy.xymanager_service.impl;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.date.DateTime;
import com.github.pagehelper.PageInfo;
import com.shxy.xymanager_common.bean.ServiceBody;
import com.shxy.xymanager_common.dto.*;
import com.shxy.xymanager_common.entity.*;
import com.shxy.xymanager_common.enums.CommonStatus;
import com.shxy.xymanager_common.exception.Asserts;
import com.shxy.xymanager_common.model.TerminalAlarmListModel;
import com.shxy.xymanager_common.model.TerminalImgAlarmParamsModel;
import com.shxy.xymanager_common.page.PageUtils;
import com.shxy.xymanager_common.util.MyDateUtils;
import com.shxy.xymanager_common.util.TerminalUtils;
import com.shxy.xymanager_common.vo.TerminalAlarmIdVo;
import com.shxy.xymanager_common.vo.TerminalAlarmSelectVo;
import com.shxy.xymanager_common.vo.UpdateTerminalAlarmParamsVo;
import com.shxy.xymanager_dao.dao.*;
import com.shxy.xymanager_service.service.CacheService;
import com.shxy.xymanager_service.service.TerminalAlarmService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.math.BigInteger;
import java.util.*;


/**
 * 告警实现层
 *
 * @author cy
 */
@Slf4j
@Service
public class TerminalAlarmServiceImpl implements TerminalAlarmService {

    @Autowired
    private TerminalImgAlarmsDao terminalImgAlarmsDao;

    @Autowired
    private TerminalPhotoDao terminalPhotoDao;

    @Autowired
    private TerminalImgAlarmsDetailsDao terminalImgAlarmsDetailsDao;

    @Autowired
    private TerminalImgAlarmParamsDao terminalImgAlarmParamsDao;

    @Autowired
    private CacheService cacheService;

    @Autowired
    DyLevelDao dyLevelDao;

    @Autowired
    LinesDao linesDao;

    @Autowired
    TowerDao towerDao;


    @Override
    public ServiceBody<TerminalAlarmListModel> getTerminalAlarmList(String requestIp, TerminalAlarmSelectVo vo) {
        TerminalAlarmListModel model = new TerminalAlarmListModel();

        Integer dyid = vo.getDyId();
        Integer lineid = vo.getLineId();
        Integer towerid = vo.getTowerId();
        Integer label = vo.getLabel();
        List<TerminalImgAlarmParams> labellist = new ArrayList<>();
        Map<Integer, TerminalImgAlarmParams> alarmParamMap = cacheService.getAlarmParamMap();
        if (label == null || label == -1) {
            alarmParamMap.forEach((key, value) -> {
                labellist.add(value);
            });
        } else {
            TerminalImgAlarmParams terminalImgAlarmParams = alarmParamMap.get(label);
            labellist.add(terminalImgAlarmParams);
        }

        Date starttime = vo.getStarttime();
        Date endtime = vo.getEndtime();
        int pageindex = vo.getPageindex();
        int pagesize = vo.getPagesize();
        long start = MyDateUtils.TimeMillSecond2Second(DateTime.of(starttime));
        long end = MyDateUtils.TimeMillSecond2Second(DateTime.of(endtime));
        List<DyAndLineAndTowerAndTermDto> dtos = new ArrayList<>();
        List<TerminalImgAlarmsDto> list = new ArrayList<>();
        List<Integer> termidlist = new ArrayList<>();
        if (dyid == null || dyid.intValue() == -1) {
            PageUtils.SetPage(pageindex, pagesize);
            list = terminalImgAlarmsDao.selectAlarmsDetails(null, labellist, BigInteger.valueOf(start), BigInteger.valueOf(end));
        } else {
            if (lineid == null || lineid.intValue() == -1) {
                dtos = dyLevelDao.selectDyAndLineAndTowerAnTermList(dyid, null, null, null, CommonStatus.EFFECTIVE.value());
            } else {
                if (towerid == null || towerid.intValue() == -1) {
                    dtos = dyLevelDao.selectDyAndLineAndTowerAnTermList(dyid, lineid, null, null, CommonStatus.EFFECTIVE.value());
                } else {
                    dtos = dyLevelDao.selectDyAndLineAndTowerAnTermList(dyid, lineid, towerid, null, CommonStatus.EFFECTIVE.value());
                }
            }
            for (DyAndLineAndTowerAndTermDto item1 : dtos) {
                for (LineAndTowerAndTermDto item2 : item1.getList()) {
                    for (TowerAndTermDto item3 : item2.getList()) {
                        for (Terminals item4 : item3.getList()) {
                            termidlist.add(item4.getId());
                        }
                    }
                }
            }
            PageUtils.SetPage(pageindex, pagesize);
            list = terminalImgAlarmsDao.selectAlarmsDetails(termidlist, labellist, BigInteger.valueOf(start), BigInteger.valueOf(end));
        }
        if (CollectionUtil.isNotEmpty(list)) {

            Map<Integer, Terminals> terminalMap = cacheService.getTerminalMap();
            Map<Integer, TowerDto> towerMap = cacheService.getTowerMap();
            Map<Integer, TerminalChannels> termchannelMap = cacheService.getTermChannelMap();
            Map<String, TerminalChannelMapper> termchannelMapMap = cacheService.getTermChannelMapMap();

//            ArrayList<BigInteger> originidlist = new ArrayList<>();
//            for (TerminalImgAlarmsDto item : list) {
//                originidlist.add(item.getPhotoOrgId());
//            }
            List<TerminalPhoto> alarmphotolist = terminalPhotoDao.selectPhotoListByOrginIdAndTermList(list);
            Map<String, TerminalPhoto> map = new HashMap<>();
            for (TerminalPhoto item : alarmphotolist) {
                map.put(item.getTermId() + "#" + item.getOrginalId(), item);
            }

//        List<TerminalAlarmListModel.AlarmBean> alarmBeans = BeanUtil.copyToList(list, TerminalAlarmListModel.AlarmBean.class, CopyOptions.create().ignoreCase());
            List<TerminalAlarmListModel.AlarmBean> alarmBeans = new ArrayList<>();
            for (TerminalImgAlarmsDto item : list) {
                TerminalAlarmListModel.AlarmBean alarmBean = new TerminalAlarmListModel.AlarmBean();
                Integer termId = item.getTermId();
                Integer channelId = item.getChannelId();

                alarmBean.setId(item.getId());
                alarmBean.setTermId(termId);
                alarmBean.setChannelId(channelId);

                Terminals terminals = terminalMap.get(termId);
                if (terminals != null) {
                    alarmBean.setDisplayName(terminals.getDisplayName());
                    Integer termtowerid = terminals.getTowerid();
                    TowerDto towerDto = towerMap.get(termtowerid);
                    if (towerDto != null) {
                        alarmBean.setTowerId(termtowerid);
                        alarmBean.setTowerName(towerDto.getName());
                        alarmBean.setLineId(towerDto.getLineId());
                        alarmBean.setLineName(towerDto.getLineName());
                    }
                }
                TerminalChannels terminalChannels = termchannelMap.get(channelId);
                if (terminalChannels != null) {
                    alarmBean.setChannnelName(terminalChannels.getChannelName());
                }
                TerminalChannelMapper terminalChannelMapper = termchannelMapMap.get(termId + "#" + channelId);
                if (terminalChannelMapper != null) {
                    alarmBean.setAlias(terminalChannelMapper.getAlias());
                }

                alarmBean.setPresetId(item.getPresetId());
                alarmBean.setPhotoOrgId(item.getPhotoOrgId());
                if (map != null) {
                    TerminalPhoto terminalPhoto = map.get(item.getTermId() + "#" + item.getPhotoOrgId());
                    if (terminalPhoto != null) {
                        Integer mediaType = terminalPhoto.getMediaType();
                        String path = terminalPhoto.getPath();
                        String photoPath = TerminalUtils.getPhotoPath(mediaType, requestIp, path);
                        alarmBean.setPath(photoPath);
                        alarmBean.setPhotoWidth(terminalPhoto.getWidth());
                        alarmBean.setPhotoHeight(terminalPhoto.getHeight());
                    } else {
                        alarmBean.setPath("");
                    }
                } else {
                    alarmBean.setPath("");
                }
                long alarmtime = MyDateUtils.TimeSecond2MillSecond(item.getAlarmTime().longValue());
                alarmBean.setAlarmTime(MyDateUtils.date(alarmtime));
                alarmBean.setLabel(item.getLabel());
                alarmBean.setName(item.getName());
                alarmBean.setEnname(item.getEnname());
                alarmBean.setProb(item.getProb());
                alarmBean.setX(item.getX());
                alarmBean.setY(item.getY());
                alarmBean.setWidth(item.getWidth());
                alarmBean.setHeight(item.getHeight());

                Integer isread = item.getIsread();
                if (isread == null) {
                    alarmBean.setIsread(CommonStatus.DELETE.value());
                } else {
                    alarmBean.setIsread(isread);
                }
                alarmBeans.add(alarmBean);
            }
            model.setList(alarmBeans);
        } else {
            model.setList(new ArrayList<>());
        }
        PageInfo pageData = PageUtils.getPageData(list);
        int currentpage = pageData.getPageNum();
        model.setCurrentpage(currentpage);
        long total = pageData.getTotal();
        model.setTotal(total);

        int pageSize = pageData.getPageSize();
        model.setPagesize(pageSize);
        int pages = pageData.getPages();
        model.setTotalpage(pages);

        return Asserts.success(model);
    }

    /**
     * 告警状态为已读
     *
     * @param vo
     * @return
     */
    @Override
    public ServiceBody<Boolean> readAlarm(TerminalAlarmIdVo vo) {
        int i = terminalImgAlarmsDetailsDao.updateReadByPrimaryKey(vo.getId().longValue(), CommonStatus.EFFECTIVE.value());
        if (i > 0) {
            return Asserts.success(true);
        } else {
            return Asserts.success(false);
        }
    }

    /**
     * 获取告警分类列表
     *
     * @return
     */
    @Override
    public ServiceBody<TerminalImgAlarmParamsModel> getAlarmTypeList() {
        TerminalImgAlarmParamsModel model = new TerminalImgAlarmParamsModel();
        ArrayList<TerminalImgAlarmParamsModel.AlarmParamBean> list = new ArrayList<>();
        Map<Integer, TerminalImgAlarmParams> beans = cacheService.getAlarmParamMap();
        beans.forEach((key, value) -> {
            TerminalImgAlarmParamsModel.AlarmParamBean alarmBean = new TerminalImgAlarmParamsModel.AlarmParamBean();
            alarmBean.setId(value.getId());
            alarmBean.setLabel(value.getLabel());
            alarmBean.setName(value.getName());
            alarmBean.setProb(value.getProb());
            list.add(alarmBean);
        });
        model.setList(list);
        return Asserts.success(model);
    }


    /**
     * 修改告警分类列表
     *
     * @return
     */
    @Override
    public ServiceBody<String> updateAlarmTypeList(UpdateTerminalAlarmParamsVo vo) {
        List<UpdateTerminalAlarmParamsVo.AlarmParamBean> list = vo.getList();
        if (CollectionUtil.isEmpty(list)) {
            return Asserts.error("数据不能为空");
        }
        ArrayList<TerminalImgAlarmParams> record = new ArrayList<>();
        for (UpdateTerminalAlarmParamsVo.AlarmParamBean item : list) {
            TerminalImgAlarmParams params = new TerminalImgAlarmParams();
            params.setId(item.getId());
            params.setLabel(item.getLabel());
            params.setProb(item.getProb());
            params.setName(item.getName());
            record.add(params);
        }
        int i = terminalImgAlarmParamsDao.updateList(record, new Date());
//        Map<Integer, TerminalImgAlarmParams> alarmParamMap = new HashMap<>();
//        List<TerminalImgAlarmParams> terminalImgAlarmParams = terminalImgAlarmParamsDao.selectAll();
//        for (TerminalImgAlarmParams item : terminalImgAlarmParams) {
//            alarmParamMap.put(item.getLabel(), item);
//        }
        cacheService.updateAlarmParamMap();
        if (i != 0) {
            return Asserts.success("修改成功");
        } else {
            return Asserts.error("修改失败");
        }
    }
}

