package com.shxy.xymanager_service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.bean.copier.CopyOptions;
import cn.hutool.core.collection.CollectionUtil;
import com.alibaba.fastjson.JSON;
import com.github.pagehelper.PageInfo;
import com.shxy.xymanager_common.bean.ServiceBody;
import com.shxy.xymanager_common.dto.DyLineAndTerminalAndChannelDto;
import com.shxy.xymanager_common.dto.TermChannelAndMapperDto;
import com.shxy.xymanager_common.entity.TerminalChannels;
import com.shxy.xymanager_common.entity.TerminalStatus;
import com.shxy.xymanager_common.enums.CommonStatus;
import com.shxy.xymanager_common.exception.Asserts;
import com.shxy.xymanager_common.model.DyLineTreeAndChannelListModel;
import com.shxy.xymanager_common.model.TerminalAllChannelListModel;
import com.shxy.xymanager_common.model.TerminalChannelListModel;
import com.shxy.xymanager_common.model.TerminalChannelMapperListModel;
import com.shxy.xymanager_common.page.PageUtils;
import com.shxy.xymanager_common.util.TerminalUtils;
import com.shxy.xymanager_common.vo.*;
import com.shxy.xymanager_dao.dao.TerminalChannelsDao;
import com.shxy.xymanager_dao.dao.TerminalPhotoDao;
import com.shxy.xymanager_dao.dao.TerminalStatusDao;
import com.shxy.xymanager_service.cache.XyCache;
import com.shxy.xymanager_service.service.TerminalChannelService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.dao.DuplicateKeyException;
import org.springframework.stereotype.Service;

import java.sql.SQLException;
import java.sql.SQLIntegrityConstraintViolationException;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 装置通道实现层
 */
@Service
@Slf4j
public class TerminalChannelServiceImpl implements TerminalChannelService {

    @Autowired
    TerminalChannelsDao terminalChannelsDao;

    @Autowired
    TerminalStatusDao terminalStatusDao;

    @Autowired
    TerminalPhotoDao terminalPhotoDao;

    /**
     * 新增通道列表
     *
     * @param vo
     * @return
     */
    @Override
    public ServiceBody<String> addChannelList(TerminalChannelVo vo) {
        List<TerminalChannels> list = BeanUtil.copyToList(vo.getList(), TerminalChannels.class, CopyOptions.create().ignoreCase());
        Date date = new Date();
        int count = terminalChannelsDao.selectChannelCount(vo.getList());
        if(count>0){
            return Asserts.error("通道重复");
        }
        int i = terminalChannelsDao.insertList(list, CommonStatus.EFFECTIVE.value(), date, date);
        if (i != 0) {
            return Asserts.success("录入成功");
        } else {
            return Asserts.error("录入失败");
        }
    }

    /**
     * 修改通道列表
     *
     * @param vo
     * @return
     */
    @Override
    public ServiceBody<String> updateChannelList(UpdateTerminalChannelVo vo) {
//        int count = terminalChannelsDao.selectChannelCountById(vo);
//        if(count>0){
//            return Asserts.success("通道重复");
//        }
        TerminalChannels bean = new TerminalChannels();
        BeanUtil.copyProperties(vo, bean, CopyOptions.create().ignoreCase());
        int i = terminalChannelsDao.updateByPrimaryKeySelective(bean, new Date());
        if (i != 0) {
            return Asserts.success("修改成功");
        } else {
            return Asserts.error("修改失败");
        }
    }

    /**
     * @param vo
     * @return
     */
    @Override
    public ServiceBody<String> deleteChannelList(TerminalChannelIdListVo vo) {
        List<TerminalChannels> list = BeanUtil.copyToList(vo.getList(), TerminalChannels.class);
        int i = terminalChannelsDao.deleteList(list, CommonStatus.DELETE.value(), new Date());
        if (i != 0) {
            return Asserts.success("删除成功");
        } else {
            return Asserts.error("删除失败");
        }
    }

    /**
     * 所有装置通道获取
     *
     * @return
     */
    @Override
    public ServiceBody<TerminalChannelListModel> getChannelList(PageVo vo) {
        int pageindex = vo.getPageindex();
        int pagesize = vo.getPagesize();
        PageUtils.SetPage(pageindex, pagesize);
        TerminalChannelListModel model = new TerminalChannelListModel();
        List<TerminalChannels> list = terminalChannelsDao.selectAllChannelList();
        boolean empty = CollectionUtil.isEmpty(list);
        if (empty) {
            model.setList(new ArrayList<>());
        } else {
            List<TerminalChannelListModel.ChannelBean> channelBeans = BeanUtil.copyToList(list, TerminalChannelListModel.ChannelBean.class, CopyOptions.create().ignoreCase());
            model.setList(channelBeans);
        }
        PageInfo pageData = PageUtils.getPageData(list);
        int currentpage = pageData.getPageNum();
        model.setCurrentpage(currentpage);
        long total = pageData.getTotal();
        model.setTotal(total);

        int pageSize = pageData.getPageSize();
        model.setPagesize(pageSize);
        int pages = pageData.getPages();
        model.setTotalpage(pages);

        return Asserts.success(model);
    }

    /**
     * 获取所有通道
     *
     * @return
     */
    @Override
    public ServiceBody<TerminalAllChannelListModel> getAllChannelList() {
        TerminalAllChannelListModel model = new TerminalAllChannelListModel();
        List<TerminalChannels> list = terminalChannelsDao.selectAllChannelList();
        boolean empty = CollectionUtil.isEmpty(list);
        if (empty) {
            model.setList(new ArrayList<>());
        } else {
            List<TerminalAllChannelListModel.ChannelBean> channelBeans = BeanUtil.copyToList(list, TerminalAllChannelListModel.ChannelBean.class, CopyOptions.create().ignoreCase());
            model.setList(channelBeans);
        }
        return Asserts.success(model);
    }

    /**
     * 装置通道获取
     *
     * @param vo
     * @return
     */
    @Override
    public ServiceBody<TerminalChannelMapperListModel> getChannelByTermid(TerminalIdVo vo) {
        Integer termId = vo.getTermid();
//        boolean b = TerminalUtils.judgeTerminalStatus(XyCache.terminalStatusMap, termId);
//        if (!b) {
//            Asserts.fail(100, "装置下线");
//        }
        TerminalChannelMapperListModel model = new TerminalChannelMapperListModel();
        List<TermChannelAndMapperDto> list = terminalChannelsDao.selectByTermid(termId, CommonStatus.EFFECTIVE.value());
        log.info("通道查出数据:{}", JSON.toJSONString(list));
        boolean empty = CollectionUtil.isEmpty(list);
        if (empty) {
            model.setList(new ArrayList<>());
        } else {
            List<TerminalChannelMapperListModel.ChannelBean> channelBeans = BeanUtil.copyToList(list, TerminalChannelMapperListModel.ChannelBean.class, CopyOptions.create().ignoreCase());
            model.setList(channelBeans);
        }
        TerminalStatus terminalStatus = terminalStatusDao.selectByPrimaryKey(termId);
        if (!BeanUtil.isEmpty(terminalStatus)) {
            model.setGpsstatus(terminalStatus.getGpsStatus());
        }
        log.info("通道查出返回数据:{}", JSON.toJSONString(model));
        return Asserts.success(model);
    }


    /**
     * 获取所有通道树状列表
     *
     * @return
     */
    @Override
    public ServiceBody<DyLineTreeAndChannelListModel> getChannelTreeList(TerminalIdVo vo) {
        DyLineTreeAndChannelListModel model = new DyLineTreeAndChannelListModel();
        List<TerminalChannels> channellist = terminalChannelsDao.selectChannelList(CommonStatus.EFFECTIVE.value());
        ArrayList<DyLineTreeAndChannelListModel.ChannelChooseBean> channels = new ArrayList<>();
        for (TerminalChannels item : channellist) {
            Integer id = item.getId();
            String channelName = item.getChannelName();
            DyLineTreeAndChannelListModel.ChannelChooseBean channelChooseBean = new DyLineTreeAndChannelListModel.ChannelChooseBean();
            channelChooseBean.setId(id);
            channelChooseBean.setName(channelName);
            channels.add(channelChooseBean);
        }
        model.setChannellist(channels);
        List<DyLineAndTerminalAndChannelDto> list = terminalChannelsDao.selectAllAndChannelByTermid(vo.getTermid(), CommonStatus.EFFECTIVE.value());
        boolean empty = CollectionUtil.isEmpty(list);
        if (empty) {
            model.setList(new ArrayList<>());
        } else {
            List<DyLineTreeAndChannelListModel.DyListBean> channelBeans = BeanUtil.copyToList(list, DyLineTreeAndChannelListModel.DyListBean.class);
            model.setList(channelBeans);
        }

        return Asserts.success(model);
    }
}
