package com.shxy.xymanager_service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.bean.copier.CopyOptions;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.date.DateTime;
import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageInfo;
import com.shxy.xymanager_common.bean.ServiceBody;
import com.shxy.xymanager_common.constant.Constants;
import com.shxy.xymanager_common.dto.TerminalInfoDto;
import com.shxy.xymanager_common.entity.TerminalPositions;
import com.shxy.xymanager_common.entity.TerminalStatus;
import com.shxy.xymanager_common.entity.Terminals;
import com.shxy.xymanager_common.enums.CommonStatus;
import com.shxy.xymanager_common.exception.Asserts;
import com.shxy.xymanager_common.model.*;
import com.shxy.xymanager_common.page.PageUtils;
import com.shxy.xymanager_common.util.MyDateUtils;
import com.shxy.xymanager_common.util.ProcessExecUtils;
import com.shxy.xymanager_common.util.StringUtils;
import com.shxy.xymanager_common.vo.*;
import com.shxy.xymanager_dao.dao.TerminalPhotoDao;
import com.shxy.xymanager_dao.dao.TerminalPositionsDao;
import com.shxy.xymanager_dao.dao.TerminalStatusDao;
import com.shxy.xymanager_dao.dao.TerminalsDao;
import com.shxy.xymanager_service.interaction.Cma;
import com.shxy.xymanager_service.service.TerminalGpsService;
import com.shxy.xymanager_service.service.TerminalService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigInteger;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 设备Gps服务实现层
 *
 * @author 晶晶
 */
@Slf4j
@Service
public class TerminalGpsServiceImpl implements TerminalGpsService {


    @Autowired
    private TerminalPositionsDao terminalPositionsDao;

    @Autowired
    TerminalPhotoDao terminalPhotoDao;


    /**
     * 开启关闭Gps
     *
     * @param vo
     * @return
     */
    @Override
    public ServiceBody<String> setTermGPS(TerminalIdAndGpsVo vo) {
//        Cma cma = new Cma("47.96.238.157", 6891);
        Integer status;
        Integer gpsstatus = vo.getGpsstatus();
        if (gpsstatus == 0) {
            status = CommonStatus.EFFECTIVE.value();
        } else {
            status = CommonStatus.DELETE.value();
        }
        String cmd = Constants.CMD + "gpsctrl --flag=1 --cmdid=" + vo.getCmdId() + "\t" + "--ctrl=" + status;
        ProcessExecUtils.exec(cmd);
        return Asserts.success("操作成功");
    }

    /**
     * 获取GPS位置
     *
     * @param vo
     * @return
     */
    @Override
    public ServiceBody<TerminalGpsModel> getTermGPS(TerminalIdVo vo) {
        TerminalGpsModel model = new TerminalGpsModel();
//        Cma cma = new Cma("47.96.238.157", 6891);
//        boolean b = cma.requestGpsInfo(vo.getTermid().toString());

        DateTime now = DateTime.now();
        TerminalPositions bean = terminalPositionsDao.selectByPrimaryKey(vo.getTermid());
        Boolean hasNew = false;
        if (!BeanUtil.isEmpty(bean)) {
            model.setRadius(bean.getRadius());
            model.setLongitude(bean.getLongitude());
            model.setLatitude(bean.getLatitude());
            model.setTermid(bean.getTermId());
            model.setQueryTime(now);
            long updatetime = MyDateUtils.TimeSecond2MillSecond(bean.getUpdateTime().longValue());
            model.setUpdatetime(MyDateUtils.date(updatetime));
            long queryTime = MyDateUtils.TimeMillSecond2Second(vo.getQueryTime());
            hasNew = updatetime < (queryTime) ? false : true;
        }
        model.setHasNew(hasNew);
        if (null != model) {
            return Asserts.success(model);
        } else {
            return Asserts.error("操作失败");
        }

    }

    @Override
    public ServiceBody<DateTime> getReturnedGPS(TerminalGpsVo vo) {
        String cmd = Constants.CMD + "gpsinfo --flag=0 --cmdid=" + vo.getCmdId() + " --clientid=10";
        ProcessExecUtils.exec(cmd);
        DateTime now = DateTime.now();
        return Asserts.success(now);
    }

    @Override
    public ServiceBody<TerminalGpsModel> getTermLastGPSPosition(Integer termid) {
        TerminalGpsModel model = new TerminalGpsModel();
        TerminalPositions bean = terminalPositionsDao.selectByPrimaryKey(termid);
        if (BeanUtil.isEmpty(bean)) {
            model.setTermid(termid);
            model.setLatitude(0);
            model.setLongitude(0);
            model.setRadius(0);
            model.setUpdatetime(new Date());
        } else {
            model.setTermid(termid);
            model.setLatitude(bean.getLatitude());
            model.setLongitude(bean.getLongitude());
            model.setRadius(bean.getRadius());
            Long updateTime = bean.getUpdateTime();
            long l = MyDateUtils.TimeSecond2MillSecond(updateTime);
            model.setUpdatetime(MyDateUtils.date(l));
        }
        return Asserts.success(model);

    }

}

