package com.shxy.xymanager_service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.date.DateField;
import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageInfo;
import com.google.common.collect.Lists;
import com.shxy.xymanager_common.bean.ServiceBody;
import com.shxy.xymanager_common.constant.Constants;
import com.shxy.xymanager_common.dto.ChannelAndTermDto;
import com.shxy.xymanager_common.dto.PhotoTimeResultDto;
import com.shxy.xymanager_common.dto.ScheduleAndRuleDto;
import com.shxy.xymanager_common.dto.ScheduleDetailsDto;
import com.shxy.xymanager_common.entity.*;
import com.shxy.xymanager_common.enums.CommonStatus;
import com.shxy.xymanager_common.exception.Asserts;
import com.shxy.xymanager_common.model.*;
import com.shxy.xymanager_common.page.PageUtils;
import com.shxy.xymanager_common.util.*;
import com.shxy.xymanager_common.vo.*;
import com.shxy.xymanager_dao.dao.*;
import com.shxy.xymanager_service.service.TerminalScheduleRuleService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.sql.Time;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 时间任务实现层
 */
@Service
@Slf4j
public class TerminalScheduleRuleServiceImpl implements TerminalScheduleRuleService {

    @Autowired
    SchedulesDao schedulesDao;

    @Autowired
    ScheduleDetailsDao scheduleDetailsDao;

    @Autowired
    TerminalScheduleDao terminalScheduleDao;

    @Autowired
    TerminalSchedulesTempDao terminalSchedulesTempDao;

    @Autowired
    TerminalsDao terminalsDao;

    @Autowired
    RequestResultsDao requestResultsDao;

    @Autowired
    TerminalScheduleDetailsDao terminalScheduleDetailsDao;

    @Value("${cma.clientid}")
    public int clientid;

    @Value("${cma.scheduletype}")
    public int scheduletype;


    /**
     * 获取时间任务规则列表
     *
     * @return
     */
    @Override
    public ServiceBody<TerminalScheduleRuleListModel> getScheduleRuleList(PageVo vo) {
        TerminalScheduleRuleListModel model = new TerminalScheduleRuleListModel();
        int pageindex = vo.getPageindex();
        int pagesize = vo.getPagesize();
        PageUtils.SetPage(pageindex, pagesize);
        List<Schedules> schedules = schedulesDao.selectAll(CommonStatus.EFFECTIVE.value());
        List<ScheduleAndRuleDto> list = schedulesDao.selectScheduleAndDetailsList(schedules, CommonStatus.EFFECTIVE.value());
        boolean empty = CollectionUtil.isEmpty(list);
        if (empty) {
            model.setList(new ArrayList<>());
        } else {
            ArrayList<TerminalScheduleRuleModel> beans = new ArrayList<>();
            for (ScheduleAndRuleDto item : list) {
                TerminalScheduleRuleModel scheduleBean = new TerminalScheduleRuleModel();
                scheduleBean.setId(item.getId());
                scheduleBean.setName(item.getName());
                scheduleBean.setRemark(item.getRemark());
                List<ScheduleDetailsDto> details = item.getList();
                ArrayList<TerminalScheduleRuleModel.ScheduleRuleBean> detailsBeans = ScheduleListUtils.getScheduleDetailsBeans(details);
                scheduleBean.setList(detailsBeans);
                beans.add(scheduleBean);
            }
            model.setList(beans);
        }
        PageInfo pageData = PageUtils.getPageData(list);
        int currentpage = pageData.getPageNum();
        model.setCurrentpage(currentpage);
        long total = pageData.getTotal();
        model.setTotal(total);

        int pageSize = pageData.getPageSize();
        model.setPagesize(pageSize);
        int pages = pageData.getPages();
        model.setTotalpage(pages);
        return Asserts.success(model);
    }


    /**
     * 获取单个时间任务规则
     *
     * @param vo
     * @return
     */
    @Override
    public ServiceBody<TerminalScheduleRuleModel> getSingleScheduleRule(ScheduleIdVo vo) {
        ScheduleAndRuleDto dto = schedulesDao.selectSingleScheduleAndDetailsList(vo.getId(), CommonStatus.EFFECTIVE.value());

        if (BeanUtil.isEmpty(dto)) {
            return Asserts.error("没有该对象");
        } else {
            TerminalScheduleRuleModel model = new TerminalScheduleRuleModel();
            model.setId(dto.getId());
            model.setName(dto.getName());
            model.setRemark(dto.getRemark());
            List<ScheduleDetailsDto> details = dto.getList();
            ArrayList<TerminalScheduleRuleModel.ScheduleRuleBean> detailsBeans = ScheduleListUtils.getScheduleDetailsBeans(details);
            model.setList(detailsBeans);
            return Asserts.success(model);
        }
    }

    /**
     * 添加时间任务规则列表
     *
     * @param vo
     * @return
     */
    @Override
    @Transactional
    public ServiceBody<String> addSchedulelRuleList(ScheduleListVo vo) {
        Date date = new Date();
        Schedules schedules = new Schedules();
        schedules.setName(vo.getName());
        schedules.setRemark(vo.getRemark());
        schedules.setStatus(CommonStatus.EFFECTIVE.value());
        schedules.setCreateTime(date);
        schedules.setUpdateTime(date);
        int i1 = schedulesDao.insertSelective(schedules);
        if (i1 != 0) {
            ArrayList<ScheduleDetails> list = ScheduleListUtils.getScheduleDetailsses(vo.getList(), schedules.getId());
            int i = scheduleDetailsDao.insertList(list, date, date);
            if (i != 0) {
                return Asserts.success("录入成功");
            } else {
                return Asserts.error("录入失败");
            }
        } else {
            return Asserts.error("录入失败");
        }
    }

    /**
     * 修改时间任务规则
     *
     * @param vo
     * @return
     */
    @Override
    @Transactional
    public ServiceBody<String> updateSchelduleRule(UpdateScheduleListVo vo) {
        Integer scheduleid = vo.getId();
        Schedules bean = schedulesDao.selectByPrimaryKey(vo.getId());
        if (BeanUtil.isEmpty(bean)) {
            return Asserts.error("没有需要修改任务规则");
        }
        Date date = new Date();
        Schedules schedule = new Schedules();
        schedule.setName(vo.getName());
        schedule.setRemark(vo.getRemark());
        schedule.setUpdateTime(date);
        schedulesDao.updateByPrimaryKeySelective(schedule);
        scheduleDetailsDao.deleteById(scheduleid);
        ArrayList<ScheduleDetails> list = ScheduleListUtils.getScheduleDetailsses(vo.getList(), scheduleid);
        int i = scheduleDetailsDao.insertList(list, date, date);
        if (i != 0) {
            return Asserts.success("修改成功");
        } else {
            return Asserts.error("修改失败");
        }
    }


    /**
     * 删除时间任务规则列表
     *
     * @param vo
     * @return
     */
    @Override
    public ServiceBody<String> deleteSchelduleRule(ScheduleIdListVo vo) {
        List<Schedules> list = BeanUtil.copyToList(vo.getList(), Schedules.class);
        int i = schedulesDao.updateStatusById(list, CommonStatus.DELETE.value(), new Date());
        if (i != 0) {
            return Asserts.success("删除成功");
        } else {
            return Asserts.error("删除失败");
        }
    }

    /**
     * 关联任务时间列表
     *
     * @param vo
     * @return
     */
    @Override
    @Transactional
    public ServiceBody<GetScheduleRequestIdListModel> relateSchelduleRule(RelateTerminalListRuleIdVo vo) {
        GetScheduleRequestIdListModel model = new GetScheduleRequestIdListModel();
       /* List<TerminalSchedulesTemp> list = terminalSchedulesTempDao.selectByTermAndChannel(vo.getList(), CommonStatus.DELETE.value());
        if (CollectionUtil.isNotEmpty(list)) {
            return Asserts.error("有装置时间尚未下发成功");
        }*/
        List<RelateTerminalListRuleIdVo.Items> termlist = vo.getList();
        Integer scheduleid = vo.getScheduleid();

        List<ChannelAndTermDto> terminalsList = terminalsDao.selectByIdList(termlist, CommonStatus.EFFECTIVE.value());
        if (CollectionUtil.isEmpty(terminalsList)) {
            return Asserts.error("没有该装置");
        }

        ScheduleAndRuleDto dto = schedulesDao.selectSingleScheduleAndDetailsList(scheduleid, CommonStatus.EFFECTIVE.value());
        if (BeanUtil.isEmpty(dto)) {
            return Asserts.error("没有该拍照时间规则");
        }
        List<ScheduleDetailsDto> dtoList = dto.getList();
        if (CollectionUtil.isEmpty(dtoList)) {
            return Asserts.error("没有该拍照时间规则");
        }


        ArrayList<GetScheduleRequestIdListModel.RequestBean> requestIdList = new ArrayList<>();
        for (int x = 0; x < terminalsList.size(); x++) {
            ChannelAndTermDto channelAndTermDto = terminalsList.get(x);
            int requestId = Constants.REQUEST_ID.addAndGet(1);
            int offset = 0;
            for (int i = 0; i < termlist.size(); i++) {
                if (channelAndTermDto.getTermid().intValue() == termlist.get(i).getTermid().intValue()) {
                    offset = termlist.get(i).getOffset();
                }
            }
//            int offset = RandomUtil.randomInt(10);
            String timestr = ScheduleListUtils.relateTime(dtoList, offset);

            String cmd = Constants.CMD + "schedule --group=" + dtoList.size() + " --flag=1 --clientid=10 --cmdid="
                    + channelAndTermDto.getCmdid() + " --reqid=" + requestId + " --channel=" + channelAndTermDto.getChannelid() + " " +
                    timestr;
            ProcessExecUtils.exec(cmd);

            log.info("cma下发时间表命令", cmd);
            GetScheduleRequestIdListModel.RequestBean requestBean = new GetScheduleRequestIdListModel.RequestBean();
            requestBean.setTermid(channelAndTermDto.getTermid());
            requestBean.setChannelid(channelAndTermDto.getChannelid());
            requestBean.setRequestid(requestId);
            requestIdList.add(requestBean);

            Date date = new Date();
            TerminalSchedulesTemp temp = new TerminalSchedulesTemp();
            temp.setTermId(channelAndTermDto.getTermid());
            temp.setChannelId(channelAndTermDto.getChannelid());
            temp.setScheduleId(scheduleid);
            temp.setRequestId(requestId);
            temp.setStatus(CommonStatus.DELETE.value());
            temp.setOffset(offset);
            temp.setCreateTime(date);
            temp.setUpdateTime(date);
            terminalSchedulesTempDao.insertSelective(temp);
        }
        model.setList(requestIdList);
        return Asserts.success(model);
    }


    /**
     * 查询拍照时间表任务是否下发成功
     *
     * @param vo
     * @return
     */
    @Override
    @Transactional
    public ServiceBody<ScheduleRequestIdListModel> checkScheldule(RequestIdListVo vo) {
        /*
         * 当定时任务或者用户主动查询下发状态时
         * */
        ScheduleRequestIdListModel model = new ScheduleRequestIdListModel();
        List<Integer> requestidlist = new ArrayList<>();
        List<RequestIdListVo.RequestBean> list = vo.getList();
        if (CollectionUtil.isEmpty(list)) {
            return Asserts.error("查询数据不能缺少");
        }
        for (RequestIdListVo.RequestBean it : list) {
            requestidlist.add(it.getRequestid());
        }
        if (CollectionUtil.isEmpty(requestidlist)) {
            return Asserts.error("查询编号列表缺少");
        }
        List<TerminalSchedulesTemp> resultsList = terminalSchedulesTempDao.selectByRequestId(requestidlist, CommonStatus.EFFECTIVE.value());
        ArrayList<ScheduleRequestIdListModel.RequestStatusBean> modellist = new ArrayList<>();
        if (CollectionUtil.isEmpty(resultsList)) {
            for (RequestIdListVo.RequestBean it : list) {
                ScheduleRequestIdListModel.RequestStatusBean requestBean = new ScheduleRequestIdListModel.RequestStatusBean();
                requestBean.setRequestid(it.getRequestid());
                requestBean.setChannelid(it.getChannelid());
                requestBean.setTermid(it.getTermid());
                requestBean.setStatus(CommonStatus.DELETE.value());
                modellist.add(requestBean);
            }
            model.setList(modellist);
            return Asserts.success(model);
        } else {
            for (RequestIdListVo.RequestBean it : list) {
                ScheduleRequestIdListModel.RequestStatusBean requestBean = new ScheduleRequestIdListModel.RequestStatusBean();
                requestBean.setRequestid(it.getRequestid());
                requestBean.setChannelid(it.getChannelid());
                requestBean.setTermid(it.getTermid());
                requestBean.setStatus(CommonStatus.DELETE.value());
                for (int i = 0; i < resultsList.size(); i++) {
                    if (it.getRequestid().intValue() == requestidlist.get(i).intValue()) {
                        requestBean.setStatus(CommonStatus.EFFECTIVE.value());
                    }
                }
                modellist.add(requestBean);
            }
            model.setList(modellist);
        }
        return Asserts.success(model);
    }


    /**
     * 获取通道的规则时间表
     *
     * @param vo
     * @return
     */
    @Override
    public ServiceBody<TerminalScheduleRuleTimeListModel> getChannelSchelduleRule(TerminalAndChannelIdVo vo) {
        TerminalScheduleRuleTimeListModel model = new TerminalScheduleRuleTimeListModel();
        TerminalSchedule mapper = terminalScheduleDao.selectByChannelId(vo.getChannelid(), vo.getTerminalid());
        if (BeanUtil.isEmpty(mapper)) {
            model.setList(new ArrayList<>());
            return Asserts.success(model);
        }
        Integer offset = mapper.getOffset();
        if (offset == null) {
            offset = 0;
        }
        model.setOffset(offset);
        if (mapper == null) {
            model.setList(new ArrayList<>());
        } else {
            Integer scheduleId = mapper.getScheduleId();
            ScheduleAndRuleDto bean = schedulesDao.selectSingleScheduleAndDetailsList(scheduleId, CommonStatus.EFFECTIVE.value());
            if (BeanUtil.isEmpty(bean)) {
                model.setList(new ArrayList<>());
            } else {
                List<ScheduleDetailsDto> list = bean.getList();
                if (CollectionUtil.isEmpty(list)) {
                    model.setList(new ArrayList<>());
                } else {
                    ArrayList<TerminalScheduleRuleModel.ScheduleRuleBean> detailsBeans = ScheduleListUtils.getScheduleDetailsBeans(list);
                    ArrayList<String> timestrlist = new ArrayList<>();
                    for (TerminalScheduleRuleModel.ScheduleRuleBean item : detailsBeans) {
                        DateTime startTime = MyDateUtils.offsetMinute(item.getStartTime(), offset);
                        if (startTime.isAfterOrEquals(MyDateUtils.endOfDay(item.getStartTime()))) {
                            startTime = MyDateUtils.endOfDay(item.getStartTime());
                        }
                        DateTime endTime = MyDateUtils.offsetMinute(item.getEndTime(), offset);
                        if (endTime.isAfterOrEquals(MyDateUtils.endOfDay(item.getEndTime()))) {
                            endTime = MyDateUtils.endOfDay(item.getEndTime());
                        }

//                        Time startTime = item.getStartTime();
//                        Time endTime = item.getEndTime();
                        Integer span = item.getSpan();
                        List<DateTime> dateTimes = MyDateUtils.rangeToList(startTime, endTime, DateField.MINUTE, span);
                        for (DateTime data : dateTimes) {
                            String dateTime = DateUtil.formatTime(data);
                            timestrlist.add(dateTime);
                        }
                    }
                    model.setList(timestrlist);
                }
            }
        }
        return Asserts.success(model);
    }


    //调用CMA获取装置的拍照时间表详情
    @Override
    public ServiceBody<GetModel> cmaSchelduleDetials(TerminalAndChannelIdVo vo) {
        GetModel model = new GetModel();

        Integer terminalid = vo.getTerminalid();
        Integer channelid = vo.getChannelid();
        String cmdIdByTermId = terminalsDao.getCmdIdByTermId(terminalid);

        int requestId = Constants.REQUEST_ID.addAndGet(1);
        String cmd = Constants.CMD + "schedule --cmdid=" + cmdIdByTermId + " --reqid=" + requestId + " --clientid=10 --flag=0 --channel=" + channelid;
        ProcessExecUtils.exec(cmd);
        model.setRequestId(requestId);
        return Asserts.success(model);
    }


    /*获取Cma调用获取装置拍照时间表结果*/
    @Override
    public ServiceBody<TerminalScheduleRuleTimeListModel> getCmaSchelduleDetials(RequestIdVo vo) {
        TerminalScheduleRuleTimeListModel model = new TerminalScheduleRuleTimeListModel();
        RequestResults results = requestResultsDao.selectByRequestId(vo.getRequestid());
        if (null != results) {
            String resultsData = results.getData();
            if (StringUtils.isNotBlank(resultsData)) {
                JSONObject resultObj = JSONObject.parseObject(resultsData);
                if (null != resultObj.get("groupData")) {
                    List<PhotoTimeResultDto> resultDtoList = JSONArray.parseArray(resultObj.get("groupData").toString(), PhotoTimeResultDto.class);
                    List<String> resultDetails = ScheduleListUtils.getResultDetails(resultDtoList);
                    model.setList(resultDetails);
                    model.setIsNew(true);
                }
            }
        }
        return Asserts.success(model);
    }
}
