package com.shxy.xymanager_service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.bean.copier.CopyOptions;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.date.DateTime;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageInfo;
import com.shxy.xymanager_common.bean.ServiceBody;
import com.shxy.xymanager_common.constant.Constants;
import com.shxy.xymanager_common.dto.*;
import com.shxy.xymanager_common.entity.TerminalChannelMapper;
import com.shxy.xymanager_common.entity.TerminalStatus;
import com.shxy.xymanager_common.entity.Terminals;
import com.shxy.xymanager_common.enums.CommonStatus;
import com.shxy.xymanager_common.enums.GloableParamsType;
import com.shxy.xymanager_common.exception.Asserts;
import com.shxy.xymanager_common.model.*;
import com.shxy.xymanager_common.page.PageUtils;
import com.shxy.xymanager_common.util.MyDateUtils;
import com.shxy.xymanager_common.util.ProcessExecUtils;
import com.shxy.xymanager_common.util.StringUtils;
import com.shxy.xymanager_common.util.TerminalUtils;
import com.shxy.xymanager_common.vo.*;
import com.shxy.xymanager_dao.dao.*;
import com.shxy.xymanager_service.cache.XyCache;
import com.shxy.xymanager_service.service.CacheService;
import com.shxy.xymanager_service.service.TerminalService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.validation.constraints.NotNull;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;


/**
 * 设备服务实现层
 *
 * @author 晶晶
 */
@Slf4j
@Service
public class TerminalServiceImpl implements TerminalService {

    @Autowired
    private TerminalsDao terminalsDao;

    @Autowired
    private TerminalChannelMapperDao terminalChannelMapperDao;

    @Autowired
    TerminalPhotoDao terminalPhotoDao;

    @Autowired
    DyLevelDao dyLevelDao;

    @Autowired
    TerminalStatusDao terminalStatusDao;

    @Autowired
    LinesDao linesDao;

    @Autowired
    RequestResultsDao requestResultsDao;

    @Autowired
    CacheService cacheService;


    /**
     * 获取所有设备列表
     *
     * @return
     */
    @Override
    public ServiceBody<TerminalListModel> getTerminalList(TerminalSelectVo vo) {
        Map<Integer, TowerDto> towerMap = cacheService.getTowerMap();
        Map<Integer, TermAndChannelDto> termAndChannelMap = cacheService.getTermAndChannelMap();
        Integer dyid = vo.getDyId();
        Integer lineid = vo.getLineId();
        Integer tower = vo.getTowerId();
        String search = vo.getSearch();
        if (StrUtil.isEmpty(search)) {
            search = null;
        }
        TerminalListModel model = new TerminalListModel();
        int pageindex = vo.getPageindex();
        int pagesize = vo.getPagesize();
        PageUtils.SetPage(pageindex, pagesize);
        List<TerminalsAndStatusDto> list2 = terminalsDao.selectTermAndStatusList(null, dyid, lineid, tower, search);
        boolean empty = CollectionUtil.isEmpty(list2);
        if (empty) {
            model.setList(new ArrayList<>());
        } else {
            ArrayList<TerminalListModel.TerminalsBean> beanlist = new ArrayList<>();
            for (TerminalsAndStatusDto item : list2) {
                if (BeanUtil.isNotEmpty(item)) {
                    TerminalListModel.TerminalsBean terminalsBean = new TerminalListModel.TerminalsBean();
                    terminalsBean.setCmdId(item.getCmdid());
                    Integer towerid = item.getTowerid();
                    terminalsBean.setId(item.getId());
                    terminalsBean.setTowerId(towerid);
                    TowerDto towerDto = towerMap.get(towerid);
                    if (BeanUtil.isNotEmpty(towerDto)) {
                        terminalsBean.setTowerName(towerDto.getName());
                        terminalsBean.setLineId(towerDto.getLineId());
                        terminalsBean.setLineName(towerDto.getLineName());
                    }
                    terminalsBean.setCmdId(item.getCmdid());
                    terminalsBean.setOrgId(item.getOrgId());
                    terminalsBean.setEquipName(item.getEquipName());
                    terminalsBean.setDisplayName(item.getDisplayName());
                    terminalsBean.setModel(item.getModel());
                    terminalsBean.setEssentialInfoVersion(item.getEssentialInfoVersion());
                    terminalsBean.setHasPan(item.getHasPan());
                    terminalsBean.setBsManufacturer(item.getBsManufacturer());
                    terminalsBean.setBsProductionDate(item.getBsProductionDate());
                    terminalsBean.setBsIdentifier(item.getBsIdentifier());
                    terminalsBean.setLatitude(item.getLatitude());
                    terminalsBean.setLongitude(item.getLongitude());
                    terminalsBean.setSignalStrength4g(item.getSignalStrength4g());
                    terminalsBean.setBootTime(item.getBootTime());
                    terminalsBean.setBatteryCapacity(item.getBatteryCapacity());
                    terminalsBean.setBatteryVoltage(item.getBatteryVoltage());
                    terminalsBean.setLastHeartbeat(item.getLastHeartbeat());
                    terminalsBean.setStatus(item.getStatus());
                    boolean b = TerminalUtils.judgeTerminalStatus(item.getLastHeartbeat());
                    terminalsBean.setIsonline(b);
                    TermAndChannelDto termAndChannelDto = termAndChannelMap.get(item.getId());
                    ArrayList<TerminalListModel.ChannelBeans> list = new ArrayList<>();
                    if (BeanUtil.isEmpty(termAndChannelDto)) {
                        terminalsBean.setList(list);
                    } else {
                        List<TermChannelAndMapperDto> channellist = termAndChannelDto.getList();
                        if (CollectionUtil.isEmpty(channellist)) {
                            terminalsBean.setList(list);
                        } else {
                            for (TermChannelAndMapperDto dto : channellist) {
                                TerminalListModel.ChannelBeans e = new TerminalListModel.ChannelBeans();
                                e.setAlias(dto.getAlias());
                                e.setId(dto.getChannelid());
                                e.setName(dto.getChannelname());
                                list.add(e);
                            }
                            terminalsBean.setList(list);
                        }
                    }
                    beanlist.add(terminalsBean);
                }
            }
            model.setList(beanlist);
        }
        PageInfo pageData = PageUtils.getPageData(list2);
        int currentpage = pageData.getPageNum();
        model.setCurrentpage(currentpage);
        long total = pageData.getTotal();
        model.setTotal(total);

        int pageSize = pageData.getPageSize();
        model.setPagesize(pageSize);
        int pages = pageData.getPages();
        model.setTotalpage(pages);
        return Asserts.success(model);
    }

    /**
     * 添加设备信息
     *
     * @param vo
     * @return
     */
    @Override
    public ServiceBody<String> addTerminal(TerminalVo vo) {
        String cmdId = vo.getCmdId();
        Terminals terminals = new Terminals();
        BeanUtil.copyProperties(vo, terminals, CopyOptions.create().ignoreCase());
        Date time = new Date();
        Terminals bean = terminalsDao.selectByCmdid(cmdId, CommonStatus.EFFECTIVE.value());
        if (BeanUtil.isNotEmpty(bean)) {
            return Asserts.error("该装置已存在");
        }
        int i = terminalsDao.insertList(terminals, CommonStatus.EFFECTIVE.value(), time, time);
        Integer termid = terminals.getId();
        List<TerminalVo.ChannelItem> channelId = vo.getList();
        if (CollectionUtil.isNotEmpty(channelId)) {
            List<TerminalChannelMapper> list = new ArrayList<>();
            for (TerminalVo.ChannelItem item : channelId) {
                TerminalChannelMapper record = new TerminalChannelMapper();
                record.setChannelId(item.getId());
                record.setAlias(item.getAlias());
                record.setTermId(termid);
                list.add(record);
            }
            Date date = new Date();
            int i1 = terminalChannelMapperDao.insertList(list, date, date);

        }
        cacheService.updateTerminalMap();
        cacheService.updateTermAndChannelMap();
        cacheService.updateTermChannelMapMap();
        if (i != 0) {
            return Asserts.success("录入成功");
        } else {
            return Asserts.error("录入失败");
        }
    }

    /**
     * 修改装置信息
     *
     * @param vo
     * @return
     */
    @Override
    public ServiceBody<String> updateTerminal(UpdateTerminalVo vo) {
        Integer termid = vo.getId();
        List<UpdateTerminalVo.Item> channelId = vo.getList();
        Terminals terminals = new Terminals();
        BeanUtil.copyProperties(vo, terminals, true);
        int i = terminalsDao.updateByPrimaryKeySelective(terminals, new Date());
        terminalChannelMapperDao.deleteByTermId(termid);
        if (CollectionUtil.isNotEmpty(channelId)) {
            List<TerminalChannelMapper> list = new ArrayList<>();
            for (UpdateTerminalVo.Item item : channelId) {
                TerminalChannelMapper record = new TerminalChannelMapper();
                record.setChannelId(item.getId());
                record.setAlias(item.getAlias());
                record.setTermId(termid);
                list.add(record);
            }
            Date date = new Date();
            terminalChannelMapperDao.insertList(list, date, date);
        }
        cacheService.updateTerminalMap();
        cacheService.updateTermAndChannelMap();
        cacheService.updateTermChannelMapMap();
        if (i != 0) {
            return Asserts.success("修改成功");
        } else {
            return Asserts.error("修改失败");
        }
    }

    /**
     * 删除线路
     *
     * @param vo
     * @return
     */
    @Override
    public ServiceBody<String> deleteTerminal(TerminalIdListVo vo) {
        ArrayList<Terminals> list = new ArrayList<>();
        List<TerminalIdVo> beans = vo.getList();
        for (TerminalIdVo item : beans) {
            Terminals terminals = new Terminals();
            terminals.setId(item.getTermid());
            list.add(terminals);
        }
        int i = terminalsDao.deleteById(list, CommonStatus.DELETE.value(), new Date());
        cacheService.updateTerminalMap();
        if (i != 0) {
            return Asserts.success("删除成功");
        } else {
            return Asserts.error("删除失败");
        }
    }


    /**
     * 装置复位
     *
     * @param cmId
     * @return
     */
    @Override
    public ServiceBody<String> resetTerminal(String cmId) {
//        Cma cma = new Cma("47.96.238.157", 6891);
        String cmd = Constants.CMD + "reset --cmdid=" + cmId + " --mode=0";
        Integer retCode = ProcessExecUtils.exec(cmd);
//        boolean reset = cma.reset(vo.getTermid().toString(), (short) 0x01);
        if (retCode == 0) {
            return Asserts.success("装置复位成功");
        } else {
            return Asserts.error("装置复位失败");
        }
    }


    @Override
    public ServiceBody<TerminalStatusModel> getTerminalStatus(Integer termId) {
        TerminalStatusModel model = new TerminalStatusModel();
        String cmdId = terminalsDao.getCmdIdByTermId(termId);
        String cmd = Constants.CMD + "runningstatus --flag=0 --cmdid=" + cmdId;
        ProcessExecUtils.exec(cmd);

        /* TerminalModel model = new TerminalModel();*/
        /* TerminalInfoDto dto = terminalsDao.getTerminalInfo(termId);*/
        /*if (null != dto) {*/
        /*    BigInteger updatetime = MyDateUtils.TimeSecond2MillSecond(dto.getWsUpdateTime().longValue());
            BeanUtils.copyProperties(dto, model);*/
        DateTime now = DateTime.now();
        model.setQueryTime(now);
      /*      model.setWsUpdateTime(MyDateUtils.date(updatetime.longValue()).toString());
        }*/

        return Asserts.success(model);
    }

    @Override
    public ServiceBody<TerminalStatusInfoModel> getLastedTerminalStatus(TerminalStatusVo vo) {
        TerminalStatusInfoModel model = new TerminalStatusInfoModel();
        Integer termId = vo.getTermId();
        TerminalStatus bean = terminalStatusDao.selectByPrimaryKey(termId);
        Boolean hasNew = false;
        if (BeanUtil.isNotEmpty(bean)) {
            Map<Integer, Terminals> terminalMap = cacheService.getTerminalMap();
            Terminals terminals = terminalMap.get(termId);
            if (BeanUtil.isNotEmpty(terminals)) {
                model.setCmId(terminals.getCmdid());
            }
            model.setBatteryCapacity(bean.getBatteryCapacity());
            model.setBatteryVoltage(bean.getBatteryVoltage());
            model.setConnectionState(bean.getConnectionState());
            model.setFloatingCharge(bean.getFloatingCharge());
            model.setTermId(termId);
            model.setTotalWorkingTime(bean.getTotalWorkingTime());
            model.setWorkingTime(bean.getWorkingTime());
            model.setWsUpdateTime(bean.getWsUpdateTime());
            BigInteger wsUpdateTime = bean.getWsUpdateTime();
            long queryTime = MyDateUtils.TimeMillSecond2Second(vo.getQueryTime());
            hasNew = wsUpdateTime.longValue() < queryTime ? false : true;

        }
        model.setIsNew(hasNew);
        return Asserts.success(model);
    }

    @Override
    public ServiceBody<TerminalUpdateModel> updateTerminalId(TerminalIdUpdateVo vo) {
        TerminalUpdateModel model = new TerminalUpdateModel();
        String cmd = Constants.CMD + "termid --flag=1 --cmdid=" + vo.getCmdId() + " --newcmdid=" + vo.getNewCmdId();
        ProcessExecUtils.exec(cmd);
        model.setTermId(vo.getTermId());

        int result = terminalsDao.updateCmd(vo);
        if (result > 0) {
            cacheService.updateTerminalMap();
            return Asserts.success(model);
        }
        return Asserts.error("装置ID修改失败");

    }

    /**
     * 根据通道编号获取装置列表
     *
     * @param vo
     * @return
     */
    @Override
    public ServiceBody<DyLineAndTermModel> getTermListByChannel(TerminalChannelIdVo vo) {
        Integer id = vo.getId();
        DyLineAndTermModel model = new DyLineAndTermModel();
        List<DyLineAndTerminalNoHeartDto> list = dyLevelDao.selectTreeListByChannelId(id, CommonStatus.EFFECTIVE.value());
        list.stream().forEach(var -> {
            var.getList().forEach(item -> {
                item.getList().forEach(terminalsWithHeart -> {
                    BigInteger lastheartbeat = terminalsWithHeart.getLastheartbeat();
                    boolean b = TerminalUtils.judgeTerminalStatus(lastheartbeat);
                    if (b) {
                        terminalsWithHeart.setOnlinestatus(CommonStatus.EFFECTIVE.value());
                    } else {
                        terminalsWithHeart.setOnlinestatus(CommonStatus.DELETE.value());
                    }
                });
            });
        });
        boolean empty = CollectionUtil.isEmpty(list);
        if (empty) {
            model.setList(new ArrayList<>());
        } else {
            List<DyLineAndTermModel.DyListBean> beans = BeanUtil.copyToList(list, DyLineAndTermModel.DyListBean.class, CopyOptions.create().ignoreCase());

            model.setList(beans);
        }
        return Asserts.success(model);
    }

    @Override
    public ServiceBody<GetModel> terminalIdGet(TerminalIdUpdateVo vo) {
        int requestId = Constants.REQUEST_ID.addAndGet(1);
        String cmd = Constants.CMD + "termid --clientid=10 --flag=0 --cmdid=" + vo.getCmdId() + " --reqid=" + requestId;
        ProcessExecUtils.exec(cmd);
        GetModel model = new GetModel();
        model.setRequestId(requestId);
        return Asserts.success(model);
    }

    @Override
    public ServiceBody<TerminalIdModel> selectTerminalId(Integer requestId) {
        String result = requestResultsDao.getRequestResult(requestId);
        TerminalIdModel model = new TerminalIdModel();
        if (StringUtils.isNotBlank(result)) {
            model = JSONObject.parseObject(result, TerminalIdModel.class);
            model.setIsNew(true);
        }
        return Asserts.success(model);
    }

    @Override
    @Transactional
    public ServiceBody<String> updateCoordinate(PhotoMarkVo vo) {
        Date date = new Date();
        vo.setCreateTime(date);
        if (null != vo.getId()) {
            terminalPhotoDao.deleteByMarkId(vo.getId());
            terminalPhotoDao.updatePhotoMark(vo);
        } else {
            terminalPhotoDao.addPhotoMark(vo);
        }
        if (CollectionUtil.isNotEmpty(vo.getList())) {
            terminalPhotoDao.addPhotoMarkPath(vo.getList(), vo.getId());
        }
        return Asserts.success("保存成功");
    }

    @Override
    public ServiceBody<PhotoMarkModel> getCoordinate(String requestIp, MarkReqVo vo) {
        Map<String, String> globalParams = cacheService.getGolobalMap();
        String s = globalParams.get(GloableParamsType.ImgMark.value());
        Integer integer = null;
        if (StrUtil.isEmpty(s)) {
            integer = 0;
        } else {
            integer = Integer.valueOf(s);
        }
        PhotoMarkModel model = new PhotoMarkModel();
        model.setMarkEnable(integer);
        PhotoMarkDto dto = null;
        if (vo.getNeedPic() == 0) {
            dto = terminalPhotoDao.selectPhotoMark(vo);
            if (null != dto && StringUtils.isNotBlank(dto.getPath())) {
                String photoPath = TerminalUtils.getPhotoPath(0, requestIp, dto.getPath());
                dto.setPath(photoPath);
            }
        } else {
            dto = terminalPhotoDao.selectPhotoWithoutPic(vo);
        }

        if (null != dto) {
            BeanUtils.copyProperties(dto, model);
        }
        return Asserts.success(model);
    }

    /**
     * 获取装置在线状态
     *
     * @param termId
     * @return
     */
    @Override
    public ServiceBody<TermStatusModel> getTermStatus(Integer termId) {
        TermStatusModel model = new TermStatusModel();
        TerminalStatus terminalStatus = terminalStatusDao.selectByPrimaryKey(termId);
        if (terminalStatus != null) {
            BigInteger lastHeartbeat = terminalStatus.getLastHeartbeat();
            boolean b = TerminalUtils.judgeTerminalStatus(lastHeartbeat);
            model.setIsonline(b);
        } else {
            model.setIsonline(false);
        }
        return Asserts.success(model);
    }

    /**
     * 获取数据库最新装置信息
     *
     * @param termId
     * @return
     */
    @Override
    public ServiceBody<TerminalStatusInfoModel> getLastTermInfo(Integer termId) {
        TerminalStatusInfoModel model = new TerminalStatusInfoModel();
        TerminalStatus bean = terminalStatusDao.selectByPrimaryKey(termId);
        if (!BeanUtil.isEmpty(bean)) {
            Map<Integer, Terminals> terminalMap = cacheService.getTerminalMap();
            Terminals terminals = terminalMap.get(termId);
            if (BeanUtil.isNotEmpty(terminals)) {
                model.setCmId(terminals.getCmdid());
            }
            model.setBatteryCapacity(bean.getBatteryCapacity());
            model.setBatteryVoltage(bean.getBatteryVoltage());
            model.setConnectionState(bean.getConnectionState());
            model.setFloatingCharge(bean.getFloatingCharge());
            model.setTermId(termId);
            model.setTotalWorkingTime(bean.getTotalWorkingTime());
            model.setWorkingTime(bean.getWorkingTime());
            model.setWsUpdateTime(bean.getWsUpdateTime());
        }
        return Asserts.success(model);
    }

}

