package com.shxy.xymanager_service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.bean.copier.CopyOptions;
import cn.hutool.core.collection.CollectionUtil;
import com.github.pagehelper.PageInfo;
import com.shxy.xymanager_common.bean.ServiceBody;
import com.shxy.xymanager_common.dto.TowerDto;
import com.shxy.xymanager_common.entity.Towers;
import com.shxy.xymanager_common.enums.CommonStatus;
import com.shxy.xymanager_common.exception.Asserts;
import com.shxy.xymanager_common.model.AllTowerListModel;
import com.shxy.xymanager_common.model.TowerListModel;
import com.shxy.xymanager_common.page.PageUtils;
import com.shxy.xymanager_common.vo.*;
import com.shxy.xymanager_dao.dao.TowerDao;
import com.shxy.xymanager_service.cache.XyCache;
import com.shxy.xymanager_service.service.CacheService;
import com.shxy.xymanager_service.service.TowerService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 设备服务实现层
 *
 * @author 晶晶
 */
@Slf4j
@Service
public class TowerServiceImpl implements TowerService {

    @Autowired
    private TowerDao towerDao;

    @Autowired
    private CacheService cacheService;

    @Override
    public ServiceBody addTower(TowersVo vo) {
        List<Towers> towersLst = BeanUtil.copyToList(vo.getList(), Towers.class, CopyOptions.create().ignoreCase());
        Date date = new Date();
        int i = towerDao.addTower(towersLst,CommonStatus.EFFECTIVE.value(), date);
        if (i != 0) {
            cacheService.updateTowerMap();
            return Asserts.success("录入成功");
        } else {
            return Asserts.error("录入失败");
        }
    }

    @Override
    public ServiceBody<TowerListModel> getTowerList(PageVo vo) {
        TowerListModel model = new TowerListModel();
        int pageindex = vo.getPageindex();
        int pagesize = vo.getPagesize();
        PageUtils.SetPage(pageindex, pagesize);
        List<TowerDto> list = towerDao.selectAll(CommonStatus.EFFECTIVE.value());
        boolean empty = CollectionUtil.isEmpty(list);
        if (empty) {
            model.setList(new ArrayList<>());
        } else {
            List<TowerListModel.TowerBean> beans = BeanUtil.copyToList(list, TowerListModel.TowerBean.class, CopyOptions.create().ignoreCase());
            model.setList(beans);
        }
        PageInfo pageData = PageUtils.getPageData(list);
        int currentpage = pageData.getPageNum();
        model.setCurrentpage(currentpage);
        long total = pageData.getTotal();
        model.setTotal(total);

        int pageSize = pageData.getPageSize();
        model.setPagesize(pageSize);
        int pages = pageData.getPages();
        model.setTotalpage(pages);


        return Asserts.success(model);
    }

    @Override
    public ServiceBody<String> deleteTower(TowerIdVo vo) {
        List<Towers> lines = BeanUtil.copyToList(vo.getList(), Towers.class);
        Date date = new Date();
        int i = towerDao.deleteById(lines, CommonStatus.DELETE.value(), date);
        if (i != 0) {
            cacheService.updateTowerMap();
            return Asserts.success("删除成功");
        } else {
            return Asserts.error("删除失败");
        }
    }

    @Override
    public ServiceBody<String> updateTower(UpdateTowerVo vo) {
        Towers towers = new Towers();
        BeanUtil.copyProperties(vo, towers, true);
        int i = towerDao.updateByPrimaryKeySelective(towers, new Date());
        if (i != 0) {
            cacheService.updateTowerMap();
            return Asserts.success("修改成功");
        } else {
            return Asserts.error("修改失败");
        }
    }

    @Override
    public ServiceBody<TowerDto> getTowerInfo(Integer id) {
        TowerDto dto = towerDao.getInfoByPrimaryKey(id, CommonStatus.EFFECTIVE.value());
        return Asserts.success(dto);
    }

    /**
     * 获取所有杆塔列表
     *
     * @return
     */
    @Override
    public ServiceBody<AllTowerListModel> getAllTower() {
        AllTowerListModel model = new AllTowerListModel();
        List<TowerDto> list = towerDao.selectAll(CommonStatus.EFFECTIVE.value());
        boolean empty = CollectionUtil.isEmpty(list);
        if (empty) {
            model.setList(new ArrayList<>());
        } else {
            List<AllTowerListModel.TowerBean> towerBeans = BeanUtil.copyToList(list, AllTowerListModel.TowerBean.class);
            model.setList(towerBeans);
        }
        return Asserts.success(model);
    }
}

