package com.shxy.xymanager_service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.bean.copier.CopyOptions;
import cn.hutool.core.collection.CollectionUtil;
import com.github.pagehelper.PageInfo;
import com.shxy.xymanager_common.bean.ServiceBody;
import com.shxy.xymanager_common.dto.TerminalApkInfoDto;
import com.shxy.xymanager_common.entity.TerminalUpload;
import com.shxy.xymanager_common.enums.CommonStatus;
import com.shxy.xymanager_common.exception.Asserts;
import com.shxy.xymanager_common.model.LineListModel;
import com.shxy.xymanager_common.model.TerminalApkInfoListModel;
import com.shxy.xymanager_common.model.TerminalListModel;
import com.shxy.xymanager_common.page.PageUtils;
import com.shxy.xymanager_common.util.UploadUtils;
import com.shxy.xymanager_common.vo.PageVo;
import com.shxy.xymanager_common.vo.TerminalApkVo;
import com.shxy.xymanager_common.vo.TerminalUploadVo;
import com.shxy.xymanager_dao.dao.TerminalUploadDao;
import com.shxy.xymanager_service.interaction.Cma;
import com.shxy.xymanager_service.service.UploadService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import javax.swing.text.html.parser.Entity;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 设备服务实现层
 *
 * @author 晶晶
 */
@Slf4j
@Service
public class UploadServiceImpl implements UploadService {

    @Value("${upload.path}")
    private String path;

    @Autowired
    TerminalUploadDao uploadDao;


    @Value("${cma.server}")
    private String server;

    @Value("${cma.port}")
    private int port;


    /**
     * 上传文件
     *
     * @param file,version
     * @return
     */
    @Override
    public ServiceBody<String> upload(MultipartFile file, String version) {
        String fileName = file.getOriginalFilename();
        try {
            path = UploadUtils.upload(file, path);
            TerminalUpload upload = new TerminalUpload(path, fileName, version);
            uploadDao.insert(upload);
        } catch (IOException e) {
            log.info("upload.exception", e);
        }

        return Asserts.success(path);

    }

    @Override
    public ServiceBody<TerminalApkInfoListModel> listApk(PageVo vo) {
        TerminalApkInfoListModel model = new TerminalApkInfoListModel();
        int pageindex = vo.getPageindex();
        int pagesize = vo.getPagesize();
        PageUtils.SetPage(pageindex, pagesize);
        List<TerminalApkInfoDto> apkInfoDtoList = uploadDao.selectAll();
        boolean empty = CollectionUtil.isEmpty(apkInfoDtoList);
        if (empty) {
            model.setList(new ArrayList<>());
        } else {
            List<TerminalApkInfoListModel.ApkBean> beans = BeanUtil.copyToList(apkInfoDtoList, TerminalApkInfoListModel.ApkBean.class, CopyOptions.create().ignoreCase());
            model.setList(beans);
        }
        PageInfo pageData = PageUtils.getPageData(apkInfoDtoList);
        int currentpage = pageData.getPageNum();
        model.setCurrentpage(currentpage);
        long total = pageData.getTotal();
        model.setTotal(total);

        int pageSize = pageData.getPageSize();
        model.setPagesize(pageSize);
        int pages = pageData.getPages();
        model.setTotalpage(pages);
        return Asserts.success(model);
    }

    @Override
    public ServiceBody<Boolean> issueApk(TerminalApkVo vo) {
        Cma cma = new Cma(server, port);

        vo.getCmdid().stream().forEach(var -> {
            cma.upgrade(var, vo.getPath());
        });

        return Asserts.success(true);
    }


}

