package com.shxy.xymanager_service.interaction;

import lombok.extern.slf4j.Slf4j;

@Slf4j
public class Cma {

    static {
        String osName = System.getProperties().getProperty("os.name");
        if(osName.equals("Linux"))
        {
            log.info("linux加载路径:{}",System.getProperty("user.dir")+"/libs/xympj.so");
            System.load(System.getProperty("user.dir")+"/libs/xympj.so");
        }
        else
        {
            log.info("windows加载路径:{}",System.getProperty("user.dir")+"\\libs\\xympj.dll");
           System.load(System.getProperty("user.dir")+"\\libs\\xympj.dll");

        }

        initCmaEnv();
    }

    public static byte CAPTURE_TYPE_PHOTO = 0;
    public static byte CAPTURE_TYPE_VIDEO = 1;
    public static byte CAPTURE_TYPE_LOG = 2;

    public Cma(String server, int port) {
        mCma = initCma(server, port);
    }

    @Override
    protected void finalize() {
        if (mCma != 0) {
            releaseCma(mCma);
        }
    }

    public static native boolean initCmaEnv();

    public native long initCma(String server, int port);
    public native void releaseCma(long cma);

    // act=capture [0xCB] --cmdid=[CMD_ID] --channel=[Channel No] --preset=[Preset No 255 by default] --type=[Media Type, 0: image, 1: video, 2: Log File]
    public native boolean requestCapture(String cmdid, short channel, short preset, short captureType);

    public native boolean upgrade(String cmdid, String filePath);

// act=upgrade [0xA9] --cmdid=[CMD_ID] --file=[File Path]
// act=httpupgrade [0xA6] --cmdid=[CMD_ID] type=[0: Program Package, 1: System Package, 2: Patch] --url=[HTTP Url]

    public native boolean updateSchedule(String cmdid, short channel, byte startHour, byte startMinute, byte endHour, byte endMinute, short cycle);
    public native boolean requestSchedule(String cmdid, short channel);
    // 0xA4
    public native boolean updateSamplingParam(String cmdid, short heartbeatTime);
    public native boolean requestSamplingParam(String cmdid);

    // 0xA7
    public native boolean updateCma(String cmdid, String cmaIp, int cmaPort, String domain);

    // act=termid [0xAC] --cmdid=[CMD_ID] --newcmdid=[New CMD ID] --compid=[Component Id] --orgid=[Original Id]
    public native boolean updateTermId(String cmdid, String newCmdid, String componentId, int originalId);


    // act=reset [0xAD] --cmdid=[CMD_ID] --mode=[Reset Mode: 0/1/2/3 Refer to SPEC doc]
    public native boolean reset(String cmdid, short mode);

    // act=wakeup [0xAE] --cmdid=[CMD_ID] --ref=[Reference_Revival_Time] --cycle=[Revival_Cycle in second] --duration=[Duration_Time in second]
// act=imgparams [0xC9] --cmdid=[CMD_ID] --color=[Color Select: 0, 1] --resolution=[Resolution: 1-15 255] --luminance=[Luminance: 1-100] --contrast=[Contrast: 1-100] --saturation=[Saturation: 1-100]
    public native boolean updateImageParams(String cmdid, byte color, byte resolution/*1-15, or -1=255*/, byte luminance, byte contrast, byte saturation);

    // act=gpsctrl [0XB9] --cmdid=[CMD_ID] --ctrl=[0: OFF 1: ON]
    public native boolean turnOnGps(String cmdid);
    public native boolean turnOffGps(String cmdid);


    // act=gpsinfo [0XBA] --cmdid=[CMD_ID]
    public native boolean requestGpsInfo(String cmdid);

    // act=runningstatus [0xEA] --cmdid=[CMD_ID]
    public native boolean requestRunningStatus(String cmdid);

    // act=video [0xD1] --cmdid=[CMD_ID] --channel=[Channel No] --port=[Port] ctrl=[0: off, 1: on]
    public native boolean turnOnVideo(String cmdid, short channel, int videoPort);
    public native boolean turnOffVideo(String cmdid, short channel, int videoPort);

    // act=videoparams [0xD5] --cmdid=[CMD_ID] --channel=[Channel No] --preset=[Preset No] --query=[Request Set Flag: 0, 1] format=[Video Format: 1 QVGA 2 VGA 3 480p 4 720P 5 1080P] time=[seconds]
    public native boolean updateVideoParams(String cmdid, short channel, short preset, byte format, short time);
    public native boolean requestVideoParams(String cmdid, short channel, short preset);

    private long mCma;

}
