package com.shxy.xymanager_service.service;


import com.shxy.xymanager_common.bean.ServiceBody;
import com.shxy.xymanager_common.bean.SysUser;
import com.shxy.xymanager_common.entity.SysUserSession;
import com.shxy.xymanager_common.model.SysUserModel;
import com.shxy.xymanager_common.vo.PageVo;
import com.shxy.xymanager_common.vo.SysUserUpdateVo;
import com.shxy.xymanager_common.vo.SysUserVo;
import org.apache.ibatis.annotations.Param;


/**
 * @ClassName：SysUserService
 * @Description： 用户信息表 服务类.
 * @Author： Arno_Fu
 * @CreatTime：11/26/2019 - 3:25 PM
 * @Version V1.0
 */
public interface SysUserService {

    /**
     * @param userAccount
     * @return com.chenxuan.entity.model.SysUser
     * @Description 根据用户账户获取用户
     */
    SysUser findByUserAccount(String userAccount);

    /**
     * 通过用户ID查询用户
     *
     * @param userId 用户ID
     * @return 用户对象信息
     */
     SysUser selectUserById(Long userId);

    ServiceBody<String> addUser(SysUserVo vo);




    /**
     * 校验用户名称是否唯一
     *
     * @param userName 用户名称
     * @return 结果
     */
    Boolean checkUserNameUnique(String userName);


    /**
     * 校验用户是否允许操作
     *
     * @param user 用户信息
     */
    void checkUserAllowed(SysUser user);


    /**
     * 新增用户信息
     *
     * @param user 用户信息
     * @return 结果
     */
    Integer insertUser(SysUser user);


    /**
     * 修改用户信息
     *
     * @param vo 用户信息
     * @return 结果
     */
    ServiceBody<String> updateUser(SysUserUpdateVo vo);

    /**
     * 修改用户状态
     *
     * @param user 用户信息
     * @return 结果
     */
    Boolean updateUserStatus(SysUser user);

    /**
     * 修改用户基本信息
     *
     * @param user 用户信息
     * @return 结果
     */
    Boolean updateUserProfile(SysUser user);


    /**
     * 重置用户密码
     *
     * @param user 用户信息
     * @return 结果
     */
    Boolean resetPwd(SysUser user);

    /**
     * 重置用户密码
     *
     * @param userName 用户名
     * @param password 密码
     * @return 结果
     */
    Boolean resetUserPwd(String userName, String password);

    /**
     * 通过用户ID删除用户
     *
     * @param userId 用户ID
     * @return 结果
     */
    ServiceBody<String> deleteUserById(@Param("userId") String userId);


    SysUserSession selectUserById(String sessionId);

    int updateUserSession(SysUserSession user);

    ServiceBody<SysUserModel> selectUserList(PageVo vo);

}
